<?php

namespace Ems\Controllers;

use Exception\Messages;
use Service\LogService;
use Service\OAuth\OAuthCustomImpl;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\HTTP\Kernel;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;


use Ems\Services\OcorrenciaService;
use Ems\Util\ExpectedException;


class OcorrenciaController {

    /** @var OcorrenciaService */
    protected $ocorrenciaService;
    
    const DEFAULT_ANEXO_FILE_NAME = 'anexo';
    
    public function __construct(EntityManager $entityManager, OcorrenciaService $ocorrenciaService) {
        $this->entityManager        = $entityManager;
        $this->ocorrenciaService   = $ocorrenciaService;
    }

    public function getOcorrenciasPendentes(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];
            $nrperiodoapuracao = empty($params['NRPERIODOAPURACAO']) ? null : $params['NRPERIODOAPURACAO'];

            $totalOcorrenciasPendentes = $this->ocorrenciaService->getOcorrenciasPendentes(
                $nrorg,
                $nrvinculom,
                $nrperiodoapuracao
            );
            $response->addDataSet(new DataSet('data', $totalOcorrenciasPendentes));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getOcorrenciasPeriodo(Request\Row $request, Response $response) {
        try {
            $params = $request->getRow();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];
            $nrperiodoapuracao = empty($params['NRPERIODOAPURACAO']) ? null : $params['NRPERIODOAPURACAO'];

            $idprogocorconfirmada = empty($params['IDPROGOCORCONFIRMADA']) ? null : $params['IDPROGOCORCONFIRMADA'];

            $totalOcorrenciasPendentes = $this->ocorrenciaService->getOcorrenciasPeriodo(
                $nrorg,
                $nrvinculom,
                $nrperiodoapuracao,
                $idprogocorconfirmada
            );
            $response->addDataSet(new DataSet('getOcorrenciasPeriodo', $totalOcorrenciasPendentes));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getOcorrenciasPendentesPeriodoVinculosGestor(Request\Row $request, Response $response) {
        try {
            $params = $request->getRow();

            $nrperiodoapuracao = (int) $params['NRPERIODOAPURACAO'];
            $nrestruturam = (int) $params['NRESTRUTURAM'];
            $cdoperador = isset($params['CDOPERADOR']) ? $params['CDOPERADOR'] : null;

            $ocorrenciasPendentesVinculosGestor = $this->ocorrenciaService->getOcorrenciasPendentesPeriodoVinculosGestor($nrestruturam, $nrperiodoapuracao, $cdoperador);

            $response->addDataSet(new DataSet('getOcorrenciasPendentesPeriodoVinculosGestor', $ocorrenciasPendentesVinculosGestor));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getOcorrenciasDia(Request\Row $request, Response $response) {
        try {
            $params = $request->getRow();
            
            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];
            $dtinicioprogocor = $params['DTINICIOPROGOCOR'];
            $cdoperador = isset($params['CDOPERADOR']) ? $params['CDOPERADOR'] : null;
            
            $OcorrenciasDia = $this->ocorrenciaService->getOcorrenciasDia(
                $nrorg,
                $nrvinculom,
                $dtinicioprogocor,
                null,
                $cdoperador
            );
            
            $response->addDataSet(new DataSet('getOcorrenciasDia', $OcorrenciasDia));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getMotivoOcorFreq(Request\Row $request, DTO\Response $response) {
        try {
            $params = $request->getRow();
            $nrorg = $params['NRORG'];
            $cdOperador = $params['CDOPERADOR'] ?? null;

            $totalOcorrenciasPendentes = $this->ocorrenciaService->getMotivoOcorFreq(
                $nrorg, $cdOperador 
            );
            $response->addDataSet(new DataSet('getMotivoOcorFreq', $totalOcorrenciasPendentes));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getMotivoOcorFreqLancamentoRetroativo(Request\Row $request, DTO\Response $response) {
        try {
            $params = $request->getRow();
            $nrorg = $params['NRORG'];
            $cdOperador = $params['CDOPERADOR'] ?? null;

            $totalOcorrenciasPendentes = $this->ocorrenciaService->getMotivoOcorFreqLancamentoRetroativo(
                $nrorg, $cdOperador 
            );
            $response->addDataSet(new DataSet('getMotivoOcorFreqLancamentoRetroativo', $totalOcorrenciasPendentes));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getTpOcorrencia(Request\Row $request, DTO\Response $response) {
        try {
            $params = $request->getRow();

            $nrorg = $params['NRORG'];

            $tipoOcorrencias = $this->ocorrenciaService->getTpOcorrencia(
                $nrorg
            );
            $response->addDataSet(new DataSet('getTpOcorrencia', $tipoOcorrencias));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function setOcorrenciaFreq(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->ocorrenciaService->setOcorrenciaFreq($row);

            $response->addDataSet(new DataSet('setOcorrenciaFreq', array('success' => $success)));
        } catch (ExpectedException $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setOcorrenciasFreq(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow()->getArrayCopy();
            
            $date = $row['DATE'];
            unset($row['DATE']);

            $success = $this->ocorrenciaService->setOcorrenciasFreq($row, $date);

            $response->addDataSet(new DataSet('setOcorrenciasFreq', array('success' => $success)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function removeOcorrenciaFreq(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();

            $success = $this->ocorrenciaService->removeOcorrenciaFreq($row);

            $response->addDataSet(new DataSet('removeOcorrenciaFreq', array('success' => $success)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function removeOcorrenciasFreq(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            $date = $row['DATE'];
            unset($row['DATE']);

            $success = $this->ocorrenciaService->removeOcorrenciasFreq($row, $date);

            $response->addDataSet(new DataSet('removeOcorrenciasFreq', array('success' => $success)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function aprovarOcorrencia(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();

            $nrprogocorrencia = $row['NRPROGOCORRENCIA'];
            $cdoperador = $row['CDOPERADOR'];

            $success = $this->ocorrenciaService->aprovarOcorrencia($nrprogocorrencia, $cdoperador, $row);

            $response->addDataSet(new DataSet('aprovarOcorrencia', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function rejeitarOcorrencia(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            $nrprogocorrencia = $row['NRPROGOCORRENCIA'];
            $dsobservacao = $row['DSOBSERVACAO'];
            $cdoperador = $row['CDOPERADOR'];

            $success = $this->ocorrenciaService->rejeitarOcorrencia($nrprogocorrencia, $cdoperador, $dsobservacao);

            $response->addDataSet(new DataSet('rejeitarOcorrencia', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }


    /**
     *  Controller genérico como getter de ocorrências
     *  (Não terminado)
     */
    public function getOcorrencias(Request\Row $request, Response $response) {
        try {
            $params = $request->getRow();

            // Parâmetros básicos necessários
            $nrvinculom = $params['NRVINCULOM'];

            // Parâmetros opcionais
            $nrperiodoapuracao = empty($params['NRPERIODOAPURACAO']) ? null : $params['NRPERIODOAPURACAO'];
            $idprogocorconfirmada = empty($params['IDPROGOCORCONFIRMADA']) ? null : $params['IDPROGOCORCONFIRMADA'];
            $dtinicioprogocor = empty($params['DTINICIOPROGOCOR']) ? null : $params['DTINICIOPROGOCOR'];
            $dtfimprogocor = empty($params['DTFIMPROGOCOR']) ? null : $params['DTFIMPROGOCOR'];

            $totalOcorrenciasPendentes = $this->ocorrenciaService->getOcorrenciasPeriodo(
                $nrorg,
                $nrvinculom,
                $nrperiodoapuracao,
                $idprogocorconfirmada,
                $dtinicioprogocor,
                $dtfimprogocor
            );
            $response->addDataSet(new DataSet('getOcorrenciasPeriodo', $totalOcorrenciasPendentes));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function insertAlmocoGestor(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();

            $cdOperador = (string) $row['CDOPERADOR'];
            $nrVinculo = (int) $row['NRVINCULOM'];
            $date = (string) $row['DATE'];
            $nrMarcacao = (int) $row['NRMARCACAOPONTO'];

            $success = $this->ocorrenciaService->insertAlmocoGestor(
                $cdOperador,
                $nrVinculo,
                $date,
                $nrMarcacao
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('insertAlmocoGestor', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    /**
     *  Controller que deverá centralizar a inserção de ocorrencias de almoço. Possibilita vários tipos de formato
     * 
     *  Modos:
     *      - passando o nrmarcacaoponto da marcacao
     *      - passando o dia e hora da marcacao
     * 
     * 
     * 
     */
    public function insereOcorrenciasAlmoco(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            // Parametros necessários nos dois modos
            
            $cdOperador = (string)  $row['CDOPERADOR'];
            $nrVinculo  = (int)     $row['NRVINCULOM'];
            
            // Array de dias
            $date       = (array)   $row['DATE'];
            
            $isNrmarcacaoSetted = isset($row['NRMARCACAOPONTO']);
            
            if ($isNrmarcacaoSetted) {
                
                // salva como metodos ja existentes
                $nrMarcacao = (int)     $row['NRMARCACAOPONTO'];
                
                $success = $this->ocorrenciaService->insertAlmocoGestor(
                    $cdOperador,
                    $nrVinculo,
                    $date,
                    $nrMarcacao
                );
                
            } else {
                
                // Salva a partir da hora das marcações (os dias já estão no vetor $date)
                $horaMarcacao   = (string)  $row['HORAMARCACAO'];
                
                $success = $this->ocorrenciaService->salvaOcorrenciasAlmocoByDataMarcacao(
                    $nrVinculo,
                    $cdOperador,
                    $horaMarcacao,
                    $date
                );
            }

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('insereOcorrenciasAlmoco', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function insertAlmocoMultiplesGestor(Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();

            $cdOperador     = (string)  $row['CDOPERADOR'];
            $nrVinculo      = (int)     $row['NRVINCULOM'];
            $date           = (array)   $row['DATE'];

            $success = $this->ocorrenciaService->
                insertAlmocoMultiplesGestor($cdOperador, $nrVinculo, $date);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('insertAlmocoMultiplesGestor', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeAlmocoGestor(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrVinculo = (int) $row['NRVINCULOM'];
            $date = (string) $row['DATE'];

            $success = $this->ocorrenciaService->
                removeAlmocoGestor($nrVinculo, $date);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('removeAlmocoGestor', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function removeAlmocos(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrVinculo  = (int)     $row['NRVINCULOM'];
            $date       = (array)   $row['DATE'];

            $success = $this->ocorrenciaService->
                removeAlmocos($nrVinculo, $date);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('removeAlmocos', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function solicitaCompensacaoFaltas(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrVinculo  = (int)     $row['NRVINCULOM'];
            $date       = (array)   $row['DATE'];

            $status = $this->ocorrenciaService->
                solicitaCompensacaoFaltas($nrVinculo, $date);

            $response->addDataSet(new DataSet('solicitaCompensacaoFaltas', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function solicitaAbonoFaltas(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrVinculo      = (int)     $row['NRVINCULOM'];
            $date           = (array)   $row['DATE'];
            $dsobservacao   = (string)  $row['DSOBSERVACAO'];
            $file           = (string)  $row['FILE'];
            $nmFile         = (string)  ($row['NMFILE'] ?? self::DEFAULT_ANEXO_FILE_NAME);
            $nrMotivo       = (string)  ($row['NRMOTIVOOCORFREQ'] ?? null);
            $cdTabecdi      = (string)  ($row['CDTABECDI']      ?? null);
            $cdDiagnost     = (string)  ($row['CDDIAGNOST']     ?? null);
            $nrPessoa       = (string)  ($row['NRPESSOA']       ?? null);

            $success = $this->ocorrenciaService->solicitaAbonoFaltas(
                $nrVinculo,
                $date,
                $dsobservacao,
                $file,
                $nmFile,
                $nrMotivo,
                $cdTabecdi,
                $cdDiagnost,
                $nrPessoa
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('solicitaAbonoFaltas', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getOcorrenciaFile(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrOcorrencia = (int) $row['NRPROGOCORRENCIA'];

            $file = $this->ocorrenciaService->
                getOcorrenciaFile($nrOcorrencia);

            $response->addDataSet(new DataSet('getOcorrenciaFile', $file));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function solicitarCompensacaoHoras(
        Request\Row $request,
        Response $response
    ) {
        $row = $request->getRow();

        $nrVinculo = (int) $row['NRVINCULOM'];
        $date = (string) $row['DATE'];

        try {
            $status = $this->ocorrenciaService->solicitarCompensacaoHoras(
                $nrVinculo, $date
            );

            $response->addDataSet(new DataSet('solicitarCompensacaoHoras', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function solicitarHorasExtras(
        Request\Row $request,
        Response $response
    ) {
        $row = $request->getRow();

        $nrVinculo      = (int)     $row['NRVINCULOM'];
        $cdOperador     =           $row['CDOPERADOR'] ?? null;
        $dsobservacao   = (string)  $row['DSOBSERVACAO'];
        $file           = (string)  ($row['FILE'] ?? null);
        $date           = (string)  $row['DATE'];

        try {
            $status = $this->ocorrenciaService->solicitarHorasExtras(
                $nrVinculo, $dsobservacao, $file, $date,
                $this->ocorrenciaService::APROVAHE_VALIDA_EXISTENCIA_CALCULO,
                $this->ocorrenciaService::APROVAHE_EXIGE_APROVACAO,
                $cdOperador
            );

            $response->addDataSet(new DataSet('solicitarHorasExtras', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getEventosAtivos(
        Request\Row $request,
        Response $response
    ) {
        try {
            $eventos = $this->ocorrenciaService->getEventosAtivos();

            $response->addDataSet(new DataSet('getEventosAtivos', $eventos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getDiagnost(
        Request\Row $request,
        Response $response
    ) {
        try {
            $diagnost = $this->ocorrenciaService->getDiagnost();

            $response->addDataSet(new DataSet('getDiagnost', $diagnost));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getPessoaConselhoReg(
        Request\Row $request,
        Response $response
    ) {
        try {
            $pessoaConselhoReg = $this->ocorrenciaService->getPessoaConselhoReg();

            $response->addDataSet(new DataSet('getPessoaConselhoReg', $pessoaConselhoReg));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getHoradiah(
        Request\Row $request,
        Response $response
    ) {
        try {
            $params = $request->getRow();
            $nrperiodoapuracao = empty($params['NRPERIODOAPURACAO']) ? null : $params['NRPERIODOAPURACAO'];
            
            $horadiah = $this->ocorrenciaService->getHoradiah($nrperiodoapuracao);

            $response->addDataSet(new DataSet('getHoradiah', $horadiah));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function setTrocasHorario(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrVinculo      = (int)     $row['NRVINCULOM'];
            $date           = (array)   $row['DATE'];
            $dsobservacao   = (string)  $row['DSOBSERVACAO'];
            $nrHordiam      = (string)  $row['NRHORDIAM'];
            $file           = (string)  ($row['FILE'] ?? null);

            $success = $this->ocorrenciaService->setTrocasHorario(
                $nrVinculo,
                $date,
                $dsobservacao,
                $nrHordiam,
                $file
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('setTrocasHorario', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getSituFrequencias(
        Request\Row $request,
        Response $response
    ) {
        try {
            $situacoes = $this->ocorrenciaService->getSituFrequencias();

            $response->addDataSet(new DataSet('getSituFrequencias', $situacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
