<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

class ProcessamentoSolicitacaoBeneficios extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens = $this->getItensAssociativeArray();

        $nrbeneficiom          = $itens['NRBENEFICIOM']   ?? null;
        $dsobsbeneficiario     = $itens['DSOBSBENEFICIARIO']  ?? '';
        $cdTipoaltevc          = $itens['CDTIPOALTEVC']   ?? null;
        $nrpessoa              = $itens['NRPESSOA'] ?? null;
        $idtpbeneficiario      = "T";
        $qtbeneficio           = $itens['QTBENEFICIO'] ?? null;
        $dtinscbeneficiario    = isset($itens['DTINSCBENEFICIARIO']) ? DateUtil::getDataDeString(substr($itens['DTINSCBENEFICIARIO'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtcancbeneficiario    = isset($itens['DTCANCBENEFICIARIO']) ? DateUtil::getDataDeString(substr($itens['DTCANCBENEFICIARIO'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtatual               = DateUtil::getDataDeString(substr(date('d/m/Y'),0,10), DateUtil::FORMATO_BRASILEIRO, true);
        $nrorg                 = Utils::getParamters()->getNrorg();
        $nrvinculom            = $this->getSolicitacao()->getNrvinculom();
        $observacao            = $this->getObservacaoComProtocolo($dsobsbeneficiario);

        if($cdTipoaltevc === 'E') {
            ProcessamentoSolicitacaoUtil::cancelaBeneficiario($nrorg, $nrvinculom, $nrbeneficiom, $dtcancbeneficiario);
            return;
        }

        $beneficiario = ProcessamentoSolicitacaoUtil::retornaBeneficiario($nrorg, $nrvinculom, $nrbeneficiom);

        if(isset($beneficiario[0])) {
            throw new \Exception("Beneficiário já cadastrado.");
        }
        
        $vabBeneficiario = Repositories::VAB_BENEFICIARIO;
        $vabBeneficiario = new $vabBeneficiario;
        $vabBeneficiario->setNrorg($nrorg);
        $vabBeneficiario->setNrvinculom($nrvinculom);
        $vabBeneficiario->setNrpessoa($nrpessoa);
        $vabBeneficiario->setNrbeneficiom($nrbeneficiom);
        $vabBeneficiario->setDtinscbeneficiario($dtinscbeneficiario);
        $vabBeneficiario->setDtcancbeneficiario($dtcancbeneficiario);
        $vabBeneficiario->setDsobsbeneficiario($observacao);
        $vabBeneficiario->setQtbeneficio($qtbeneficio);
        $vabBeneficiario->setIdtpbeneficiario($idtpbeneficiario);
        $vabBeneficiario->setDtinclusao(DateUtil::getDataAtual(false));
        $vabBeneficiario->setDtultatu($dtatual);
        $vabBeneficiario->setIdvalordifebenef(null);
        $vabBeneficiario->setNrorginclusao(Utils::getParamters()->getNrorg());
        $vabBeneficiario->setNrorgultatu(Utils::getParamters()->getNrorg());
        $vabBeneficiario->setCdoperinclusao(Utils::getParamters()->getCdoperador());
        $vabBeneficiario->setCdoperultatu(Utils::getParamters()->getCdoperador());
        $vabBeneficiario->setNrbeneficiario(NovoCodigo::geraCodigo(Utils::getParamters()->getNrorg(), 'VAB_BENEFICIARIO', 1, 12, true));
        Utils::getEntityManager()->persist($vabBeneficiario);
        Utils::getEntityManager()->flush();
    }
    
    public function rejeitar() {}
}
