<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Util\{ NovoCodigo };

class ReconhecimentoFacialRepository{
    protected $entityManager;
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ){
        $this->connection = $entityManager->getConnection();
    }

    public function saveHashFacial(
        array $params
    ): void {
        $sql = <<<SQL
            INSERT INTO GPE_FACEID (
                NRORG,              NRFACEID,           NRPARCNEGOCIO,
                HASHFACIAL,         IDATIVO,            NRORGINCLUSAO,
                DTINCLUSAO,         CDOPERINCLUSAO,     NRORGULTATU,
                DTULTATU,           CDOPERULTATU
            )
            VALUES (
                :NRORG,             :NRFACEID,          :NRPARCNEGOCIO,
                :HASHFACIAL,        :IDATIVO,           :NRORGINCLUSAO,
                :DTINCLUSAO,        :CDOPERINCLUSAO,    :NRORGULTATU,
                :DTULTATU,          :CDOPERULTATU
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function updateHashFacial(array $params) {
        $sql = <<<SQL
            UPDATE GPE_FACEID SET
                HASHFACIAL = :P_HASHFACIAL,
                NRORGULTATU = :P_NRORGULTATU,
                DTULTATU = :P_DTULTATU,
                CDOPERULTATU = :P_CDOPERULTATU
            WHERE NRFACEID = :P_NRFACEID
                AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO 
                AND NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $result = $std->execute($params);
        
        return $result;
    }

    public function deleteHashFacial($params): bool {
        $sql = <<<SQL
            DELETE FROM GPE_FACEID
            WHERE NRFACEID = :P_NRFACEID
                AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                AND NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }

    public function getBiometriasVinculo($nrorg, $nrparcnegocio) {
        $sql = <<<SQL
            SELECT
                FACE.NRFACEID,
                FACE.HASHFACIAL,
                FACE.DTINCLUSAO,
                FACE.NRORG,
                FACE.NRPARCNEGOCIO
            FROM
                GPE_FACEID FACE
            WHERE
                FACE.NRORG = :P_NRORG
                AND FACE.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                AND FACE.IDATIVO = 'S'
SQL;

        $params = array(
            'P_NRORG' => $nrorg,
            'P_NRPARCNEGOCIO' => $nrparcnegocio
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $hashs = $std->fetchAll();

        return $hashs;
    }

    public function getFaceIdsTemp(
        $nrorg,
        array $nrVinculos
    ): array {
        
        $nrLista = NovoCodigo::geraCodigo($nrorg, 'LISTA', 1, 12, true);
        $params['P_NRLISTA'] = $nrLista;
    
        // Monta a query inicial
        $sqlTemp = "INSERT ALL ";
    
        // Acumula os valores para o insert all
        $paramsInsert = [];
        foreach ($nrVinculos as $index => $nrVinculom) {
            $sqlTemp .= "INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:P_NRLISTA_$index, :P_CDLISTA_$index, :P_NRORG_$index) ";
            $paramsInsert["P_NRLISTA_$index"] = $nrLista;
            $paramsInsert["P_CDLISTA_$index"] = $nrVinculom;
            $paramsInsert["P_NRORG_$index"] = $nrorg;
        }
    
        // Finaliza a query com o SELECT
        $sqlTemp .= "SELECT 1 FROM DUAL";
    
        // Prepara e executa o insert all
        $queryTemp = $this->connection->prepare($sqlTemp);
        $queryTemp->execute($paramsInsert);

        $sql = <<<SQL
            SELECT 
                FACE.NRFACEID,
                FACE.HASHFACIAL,
                FACE.DTINCLUSAO,
                FACE.NRORG,
                FACE.NRPARCNEGOCIO,
                VM.NRVINCULOM
            FROM GPE_FACEID FACE

            LEFT JOIN LISTA ON LISTA.NRLISTA = :P_NRLISTA 
                AND LISTA.NRORG = FACE.NRORG
            LEFT JOIN GPE_VINCULOM VM ON VM.NRORG = FACE.NRORG
                AND VM.NRVINCULOM = LISTA.CDLISTA
            LEFT JOIN GPE_PESSOA PA ON PA.NRORG = FACE.NRORG
                AND PA.NRPESSOA = VM.NRPESSOA
            LEFT JOIN PARCNEGOCIO PCN ON PCN.NRORG = FACE.NRORG
                AND PCN.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
            WHERE FACE.NRORG = :P_NRORG
                AND FACE.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG'   => $nrorg,
            'P_NRLISTA' => $nrLista 
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $solicitacoes = $std->fetchAll();

        $this->deleteTempLista($nrLista, $nrorg);

        return $solicitacoes;
    }

    public function deleteTempLista($nrLista, $nrorg) {
        $sql = <<<SQL
            DELETE FROM
                LISTA
            WHERE 
                NRLISTA = :P_NRLISTA AND NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRLISTA' => $nrLista,
            'P_NRORG'   => $nrorg 
        ];

        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
}