<?php

namespace Ems\Services;

use Doctrine\ORM\EntityManager;

use Util\Environment;
use Ems\Repository\ComunicadoAcidenteTrabalhoRepository;
use Ems\Util\Utils;
use Ems\Services\EstruturaService;
use Ems\Repository\OcorrenciaRepository;
use Ems\Util\ArrayUtil;

class ComunicadoAcidenteTrabalhoService {
    /** @var ComunicadoAcidenteTrabalhoRepository */
    public $comunicadoAcidenteTrabalhoRepository;

     /** @var EstruturaService */
     protected $estruturaService;

    /** @var Environment */
    public $environment;

    /** @var OcorrenciaRepository */
    protected $ocorrenciaRepository;

    public function __construct(
        EntityManager $entityManager,
        Environment $environment,
        ComunicadoAcidenteTrabalhoRepository $comunicadoAcidenteTrabalhoRepository,
        EstruturaService $estruturaService,
        OcorrenciaRepository $ocorrenciaRepository
    ) {
        $this->entityManager                        = $entityManager;
        $this->comunicadoAcidenteTrabalhoRepository = $comunicadoAcidenteTrabalhoRepository;
        $this->environment                          = $environment;
        $this->estruturaService                     = $estruturaService;
        $this->ocorrenciaRepository                 = $ocorrenciaRepository;
    }

    public function setComunicadoAcidenteTrabalho($row) : array 
    {   

       
        $this->entityManager->beginTransaction();

        try {
            $rowValidada = array();
            $row['CDOPERADOR'] = intval($row['CDOPERADOR']) ?? null;
            if( $row["dadosCAT"] ) {
                $dtOcorrencia = $row["dadosCAT"]['DTOCORRENCIA'];
                $hrOcorrencia = $row["dadosCAT"]['HROCORRENCIA'];
                $row["dadosCAT"]['DTHROCORRENCIAFORMAT'] = $dtOcorrencia . ' ' . $hrOcorrencia . ':00';
                $nrOcorrencia = $this->comunicadoAcidenteTrabalhoRepository->setOcorrenciaCAT($row["dadosCAT"], $row['NRORG'], $row['CDOPERADOR']);
            }
      
            if( $row["dadosVitima"] ) {
                $dtInicatend = $row["dadosVitima"]['DTINICATEND'] ?? null;
                $hrInicatend = $row["dadosVitima"]['HRINICATEND'] ?? null;
                $row["dadosVitima"]['DTHRINICATENDFORMAT'] = $dtInicatend . ' ' . $hrInicatend . ':00';
                
                if(!isset($row["dadosVitima"]['NRCEPENDERECO']) && empty(($row["dadosVitima"]['NRCEPENDERECO']))){
                   $row["dadosVitima"]['NRCEPENDERECO'] = null;
                } else {
                   $row["dadosVitima"]['NRCEPENDERECO'] = str_replace(['-', '.'], "", $row["dadosVitima"]['NRCEPENDERECO']);
                }

                if(isset($row["dadosVitima"]['QTHRATEINICATEND']) && !empty(($row["dadosVitima"]['QTHRATEINICATEND']))) {
                    $row["dadosVitima"]['QTHRATEINICATEND'] = str_replace(':', '', $row["dadosVitima"]['QTHRATEINICATEND']);
                   // $row["dadosVitima"]['QTHRATEINICATEND'] = intval($row["dadosVitima"]['QTHRATEINICATEND']);
                } else {
                    $row["dadosVitima"]['QTHRATEINICATEND'] = null;
                }

                
                if(isset($row["dadosVitima"]['QTHRATENDIMENTO']) && !empty(($row["dadosVitima"]['QTHRATENDIMENTO']))) {
                    $row["dadosVitima"]['QTHRATENDIMENTO'] = str_replace(':', '', $row["dadosVitima"]['QTHRATENDIMENTO']);
                   // $row["dadosVitima"]['QTHRATENDIMENTO'] = intval($row["dadosVitima"]['QTHRATENDIMENTO']);
                } else {
                    $row["dadosVitima"]['QTHRATENDIMENTO'] = null;
                }

                
                if(isset($row["dadosVitima"]['QTHRAPOSINICTRAB']) && !empty(($row["dadosVitima"]['QTHRAPOSINICTRAB']))) {
                    $row["dadosVitima"]['QTHRAPOSINICTRAB'] = str_replace(':', '', $row["dadosVitima"]['QTHRAPOSINICTRAB']);
                   // $row["dadosVitima"]['QTHRAPOSINICTRAB'] = intval($row["dadosVitima"]['QTHRAPOSINICTRAB']);
                } else {
                    $row["dadosVitima"]['QTHRAPOSINICTRAB'] = null;
                }
                
                $dtFimcatend = $row["dadosVitima"]['DTFIMATEND'] ?? null;
                $hrFimcatend = $row["dadosVitima"]['HRFIMCATEND'] ?? null;

                if(!is_null($hrFimcatend) && !is_null($dtFimcatend)) {
                    $row["dadosVitima"]['DTHRFIMATENDFORMAT'] = $dtFimcatend . ' ' . $hrFimcatend . ':00';
                }


                if(!isset($row["dadosVitima"]['IDINTERNACAO']) || $row["dadosVitima"]['IDINTERNACAO'] == false) {
                    $row["dadosVitima"]['IDINTERNACAO'] = 'N';
                }

                if(!isset($row["dadosVitima"]['IDAFASTAMENTO']) || $row["dadosVitima"]['IDAFASTAMENTO'] == false) {
                    $row["dadosVitima"]['IDAFASTAMENTO'] = 'N';
                }

                $nrVitima = $this->comunicadoAcidenteTrabalhoRepository->setVitima($row["dadosVitima"], $row['NRORG'], $row["dadosCAT"], $nrOcorrencia, $row['CDOPERADOR']);

               
                
            }

            if( $row["dadosParteAtingida"] ) {
                $this->comunicadoAcidenteTrabalhoRepository->setParteAtingida( $row["dadosParteAtingida"], $row['NRORG'], $nrOcorrencia, $nrVitima, $row['CDOPERADOR']);
            }
        
            if( $row["dadosFichaMedica"] ) {

                $nrFichaMedica = $this->comunicadoAcidenteTrabalhoRepository->setFichaMedica($row["dadosFichaMedica"], $row['NRORG'], $row["dadosVitima"], $nrOcorrencia, $row['CDOPERADOR']);
            }
              
            if( $row["dadosDoenca"] ) {
                if (strlen($row["dadosDoenca"]["DSDOENCAFICHAMEDICA"]) > 100) {
                    $row["dadosDoenca"]["DSDOENCAFICHAMEDICA"] = substr($row["dadosDoenca"]["DSDOENCAFICHAMEDICA"], 0, 100); 
                }
                $this->comunicadoAcidenteTrabalhoRepository->setDoenca($row["dadosDoenca"],$row['NRORG'],  $nrFichaMedica, $row['CDOPERADOR']);            
            }
    
            $this->entityManager->commit();
            return $rowValidada;
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }

        
    }

    private function validaDadosOcorrenciaCAT($rowDadosCAT) : array 
    {
        $rowDadosCAT['NRESTRUTURAM']           = $rowDadosCAT['NRESTRUTURAM']?? NULL;
        $rowDadosCAT['NRTIPOOCORRE']           = $rowDadosCAT['NRTIPOOCORRE']?? NULL;
        $rowDadosCAT['NRCLASSIFICACAO']        = $rowDadosCAT['NRCLASSIFICACAO']?? NULL;
        $rowDadosCAT['NRGRAVIDADE']            = $rowDadosCAT['NRGRAVIDADE']?? NULL;
        $rowDadosCAT['NRINFLUENCIAGERENCIAL']  = $rowDadosCAT['NRINFLUENCIAGERENCIAL']?? NULL;
        $rowDadosCAT['NRCAUSA']                = $rowDadosCAT['NRCAUSA']?? NULL;
        $rowDadosCAT['NRACAO']                 = $rowDadosCAT['NRACAO']?? NULL;
        $rowDadosCAT['DTHROCORRENCIA']         = $rowDadosCAT['DTHROCORRENCIA']?? NULL;
        $rowDadosCAT['DTHRRELATOOCORRE']       = $rowDadosCAT['DTHRRELATOOCORRE']?? NULL;
        $rowDadosCAT['DSOCORRENCIA']           = $rowDadosCAT['DSOCORRENCIA']?? NULL;
        $rowDadosCAT['IDOCORRENCIA']           = $rowDadosCAT['IDOCORRENCIA']?? NULL;
        $rowDadosCAT['QTVITIMASOCORRE']        = $rowDadosCAT['QTVITIMASOCORRE']?? 1;
        $rowDadosCAT['DSOBSERVACAO']           = $rowDadosCAT['DSOBSERVACAO']?? NULL;
        $rowDadosCAT['DSTIPOOCORRE']           = $rowDadosCAT['DSTIPOOCORRE']?? NULL;
        $rowDadosCAT['DSCLASSIFOCORRE']        = $rowDadosCAT['DSCLASSIFOCORRE']?? NULL;
        $rowDadosCAT['DSINFLUGEROCORRE']       = $rowDadosCAT['DSINFLUGEROCORRE']?? NULL;
        $rowDadosCAT['DSTIPOOCORRE']           = $rowDadosCAT['DSTIPOOCORRE']?? NULL;
        $rowDadosCAT['DSCLASSIFOCORRE']        = $rowDadosCAT['DSCLASSIFOCORRE']?? NULL;
        return $rowDadosCAT;
    }

    private function validaDadosVitima($rowDadosVitima) : array 
    {
        $rowDadosVitima['NRNATUREZA']            = $rowDadosVitima['NRNATUREZA']?? NULL;
        $rowDadosVitima['NRGRAVIDADE']           = $rowDadosVitima['NRGRAVIDADE']?? NULL;
        $rowDadosVitima['NRINFLUENCIAGERENCIAL'] = $rowDadosVitima['NRINFLUENCIAGERENCIAL']?? NULL;
        $rowDadosVitima['NROCORRENCIA']          = $rowDadosVitima['NROCORRENCIA']?? NULL;
        $rowDadosVitima['NRPARCNEGOCIO']         = $rowDadosVitima['NRPARCNEGOCIO']?? NULL;
        $rowDadosVitima['CDPAIS']                = $rowDadosVitima['CDPAIS']?? NULL;
        $rowDadosVitima['SGESTADO']              = $rowDadosVitima['SGESTADO']?? NULL;
        $rowDadosVitima['CDMUNICIPIO']           = $rowDadosVitima['CDMUNICIPIO']?? NULL;
        $rowDadosVitima['DSACIDENTE']            = $rowDadosVitima['DSACIDENTE']?? NULL;
        $rowDadosVitima['DSNATUREZAACID']        = $rowDadosVitima['DSNATUREZAACID']?? NULL;
        $rowDadosVitima['DSGRAVIDACID']          = $rowDadosVitima['DSGRAVIDACID']?? NULL;
        $rowDadosVitima['DSINFLUGERACID']        = $rowDadosVitima['DSINFLUGERACID']?? 1;
        $rowDadosVitima['QTHRAPOSINICTRAB']      = $rowDadosVitima['QTHRAPOSINICTRAB']?? NULL;
        $rowDadosVitima['DTULTDIATRABALHADO']    = $rowDadosVitima['DTULTDIATRABALHADO']?? NULL;
        $rowDadosVitima['QTDIASDEBITADOS']       = $rowDadosVitima['QTDIASDEBITADOS']?? NULL;
        $rowDadosVitima['QTDIASPERDIDOS']        = $rowDadosVitima['QTDIASPERDIDOS']?? NULL;
        $rowDadosVitima['QTDIASTRABRESTRITO']    = $rowDadosVitima['QTDIASTRABRESTRITO']?? NULL;
        $rowDadosVitima['QTHRPERDIDAS']          = $rowDadosVitima['QTHRPERDIDAS']?? NULL;
        $rowDadosVitima['IDACIDFATAL']           = $rowDadosVitima['IDACIDFATAL']?? NULL;
        $rowDadosVitima['DTOBITO']               = $rowDadosVitima['DTOBITO']?? NULL;
        $rowDadosVitima['IDFALTAEPI']            = $rowDadosVitima['IDFALTAEPI']?? NULL;
        $rowDadosVitima['IDAFASTAMENTO']         = $rowDadosVitima['IDAFASTAMENTO']?? NULL;
        $rowDadosVitima['IDINTERNACAO']          = $rowDadosVitima['IDINTERNACAO']?? NULL;
        $rowDadosVitima['IDREGPOLICIAL']         = $rowDadosVitima['IDREGPOLICIAL']?? NULL;
        $rowDadosVitima['NRREGPOLICIAL']         = $rowDadosVitima['NRREGPOLICIAL']?? NULL;
        $rowDadosVitima['IDINCAPACITADO']        = $rowDadosVitima['IDINCAPACITADO']?? NULL;
        $rowDadosVitima['DTHRINICATEND']         = $rowDadosVitima['DTHRINICATEND']?? NULL;
        $rowDadosVitima['QTHRATEINICATEND']      = $rowDadosVitima['QTHRATEINICATEND']?? NULL;
        $rowDadosVitima['DTHRFIMATEND']          = $rowDadosVitima['DTHRFIMATEND']?? NULL;
        $rowDadosVitima['QTHRATENDIMENTO']       = $rowDadosVitima['QTHRATENDIMENTO']?? NULL;
        $rowDadosVitima['DTCAT']                 = $rowDadosVitima['DTCAT']?? NULL;
        $rowDadosVitima['NRCAT']                 = $rowDadosVitima['NRCAT']?? NULL;
        $rowDadosVitima['DSLOCALCAT']            = $rowDadosVitima['DSLOCALCAT']?? NULL;
        $rowDadosVitima['DSOBSERVACAO']          = $rowDadosVitima['DSOBSERVACAO']?? NULL;

        return $rowDadosVitima;
    }

    private function validaDadosFichaMedica($rowDadosFichaMedica) : array
    {
        $rowDadosFichaMedica['NRNATUREZAEXAME']            = $rowDadosFichaMedica['NRNATUREZAEXAME']?? NULL;
        $rowDadosFichaMedica['NRCONTROLEAPTIDAOATEND'] = $rowDadosFichaMedica['NRCONTROLEAPTIDAOATEND']?? NULL;
        $rowDadosFichaMedica['NRCONTROLEAPTIDAOINSS']  = $rowDadosFichaMedica['NRCONTROLEAPTIDAOINSS']?? NULL;
        $rowDadosFichaMedica['NRQUEIXA']               = $rowDadosFichaMedica['NRQUEIXA']?? NULL;
        $rowDadosFichaMedica['NRMOTIVOAUSENCIA']       = $rowDadosFichaMedica['NRMOTIVOAUSENCIA']?? NULL;
        $rowDadosFichaMedica['NRVINCULOM']             = $rowDadosFichaMedica['NRVINCULOM']?? NULL;
        $rowDadosFichaMedica['NRPARCNEGOCIO']          = $rowDadosFichaMedica['NRPARCNEGOCIO']?? NULL;
        $rowDadosFichaMedica['NRTABRESULTEXAME']       = $rowDadosFichaMedica['NRTABRESULTEXAME']?? NULL;
        $rowDadosFichaMedica['NRESTRUTURAM']           = $rowDadosFichaMedica['NRESTRUTURAM']?? NULL;
        $rowDadosFichaMedica['NROCORRENCIA']           = $rowDadosFichaMedica['NROCORRENCIA']?? NULL;
        $rowDadosFichaMedica['NRSITUFUNCM']            = $rowDadosFichaMedica['NRSITUFUNCM']?? NULL;
        $rowDadosFichaMedica['NRSITUFUNCMPROX']        = $rowDadosFichaMedica['NRSITUFUNCMPROX']?? 1;
        $rowDadosFichaMedica['DTHRPREVFICHAMED']       = $rowDadosFichaMedica['DTHRPREVFICHAMED']?? NULL;
        $rowDadosFichaMedica['DTHREFETFICHAMED']       = $rowDadosFichaMedica['DTHREFETFICHAMED']?? NULL;
        $rowDadosFichaMedica['NRINSCRCONSELHOATEND']   = $rowDadosFichaMedica['NRINSCRCONSELHOATEND']?? NULL;
        $rowDadosFichaMedica['DSLOCALATENDIMENTO']     = $rowDadosFichaMedica['DSLOCALATENDIMENTO']?? NULL;
        $rowDadosFichaMedica['IDNEXOCAUSAL']           = $rowDadosFichaMedica['IDNEXOCAUSAL']?? NULL;
        $rowDadosFichaMedica['IDEMISSAOCAT']           = $rowDadosFichaMedica['IDEMISSAOCAT']?? NULL;
        $rowDadosFichaMedica['NRCAT']                  = $rowDadosFichaMedica['NRCAT']?? NULL;
        $rowDadosFichaMedica['NRBENEFICIO']            = $rowDadosFichaMedica['NRBENEFICIO']?? 1;
        $rowDadosFichaMedica['IDBENEFICIO']            = $rowDadosFichaMedica['IDBENEFICIO']?? NULL;
        $rowDadosFichaMedica['DTCONCLFICHAMED']        = $rowDadosFichaMedica['DTCONCLFICHAMED']?? NULL;
        $rowDadosFichaMedica['DTHRINIAFASTAMENTO']     = $rowDadosFichaMedica['DTHRINIAFASTAMENTO']?? NULL;
        $rowDadosFichaMedica['DTHRFIMAFASTAMENTO']     = $rowDadosFichaMedica['DTHRFIMAFASTAMENTO']?? NULL;
        $rowDadosFichaMedica['DTPREVRETORNO']          = $rowDadosFichaMedica['DTPREVRETORNO']?? NULL;
        $rowDadosFichaMedica['QTPESO']                 = $rowDadosFichaMedica['QTPESO']?? NULL;
        $rowDadosFichaMedica['VRALTURA']               = $rowDadosFichaMedica['VRALTURA']?? NULL;
        $rowDadosFichaMedica['VRIMC']                  = $rowDadosFichaMedica['VRIMC']?? NULL;
        $rowDadosFichaMedica['VRPULSO']                = $rowDadosFichaMedica['VRPULSO']?? NULL;
        $rowDadosFichaMedica['VRPRESSAOARTSISTOLICA']  = $rowDadosFichaMedica['VRPRESSAOARTSISTOLICA']?? NULL;
        $rowDadosFichaMedica['VRPRESSAOARTDIASTOLICA'] = $rowDadosFichaMedica['VRPRESSAOARTDIASTOLICA']?? NULL;
        $rowDadosFichaMedica['VRTEMPERATURA']          = $rowDadosFichaMedica['VRTEMPERATURA']?? NULL;
        $rowDadosFichaMedica['VREXAME']                = $rowDadosFichaMedica['VREXAME']?? NULL;
    }

    private function validaDadosParteAtingida($rowDadosParteAtingida) : array
    {   
        $rowDadosParteAtingida['NRVITPARTEATING'] = $rowDadosParteAtingida['NRVITPARTEATING']?? NULL;
        $rowDadosParteAtingida['NRPARTEATINGIDA'] = $rowDadosParteAtingida['NRPARTEATINGIDA']?? NULL;
        $rowDadosParteAtingida['NROCORRENCIA']    = $rowDadosParteAtingida['NROCORRENCIA']?? NULL;
        $rowDadosParteAtingida['DSDIAGNOSTICO']   = $rowDadosParteAtingida['DSDIAGNOSTICO']?? NULL;
        $rowDadosParteAtingida['DSOBSERVACAO']    = $rowDadosParteAtingida['DSOBSERVACAO']?? NULL;
        $rowDadosParteAtingida['LATERALIDADE']    = $rowDadosParteAtingida['LATERALIDADE']?? NULL;
    }

    private function validaDadosDoenca($rowDadosDoenca) : array
    {   
        $rowDadosDoenca['NRFICHAMEDICA']       = $rowDadosDoenca['NRFICHAMEDICA']?? NULL;
        $rowDadosDoenca['NRDOENCAFICHAMEDICA'] = $rowDadosDoenca['NRDOENCAFICHAMEDICA']?? NULL;
        $rowDadosDoenca['NRCID']               = $rowDadosDoenca['NRCID']?? NULL;
        $rowDadosDoenca['DSDIAGNOSTICO']       = $rowDadosDoenca['DSDIAGNOSTICO']?? NULL;
        $rowDadosDoenca['DSDOENCAFICHAMEDICA'] = $rowDadosDoenca['DSDOENCAFICHAMEDICA']?? NULL;
        $rowDadosDoenca['IDOCUPACIONAL']       = $rowDadosDoenca['IDOCUPACIONAL']?? NULL;
    }

    public function getComunicadoAcidenteTrabalho($row) : array 
    {      
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $row = $this->verificaPerfilAcesso($row);

        $params = [
            'P_NRORG_PADRAO'     => $nrOrgPadrao,
            'P_NRORG'            => $row['NRORG'],
            'P_NRESTRUTGEREN'    => $row['NRESTRUTGEREN'],
            'P_DTMESCOMPETENC'   => Utils::getParamters()->getDtmescomptencDiaCorrente(),
        ];

        $cat = $this->comunicadoAcidenteTrabalhoRepository->getComunicadoAcidenteTrabalho($params);;

        return $cat;
    }


    public function deleteComunicadoAcidenteTrabalho($row) : array 
    {
        $this->entityManager->beginTransaction();
        try {
            $rowValidada           = array();
            $nrDoencaFichaMedica   = $row['NRDOENCAFICHAMEDICA'] ?? null;
            $nrFichaMedica         = $row['NRFICHAMEDICA'] ?? null;
            $nrVitimaParteAtingida = $row['NRVITPARTEATING'] ?? null;
            $nrVitima              = $row['NRVITIMA'] ?? null;
            $nrOcorrencia          = $row['NROCORRENCIA'] ?? null;
            
            if(!is_null($nrDoencaFichaMedica)) {
                $this->comunicadoAcidenteTrabalhoRepository->deleteDoenca($nrDoencaFichaMedica, $row['NRORG'], $nrFichaMedica);            
            } 

            if(!is_null( $nrFichaMedica)) {
                $deleteFichaMedica = $this->comunicadoAcidenteTrabalhoRepository->deleteFichaMedica($nrFichaMedica, $row['NRORG'], $nrOcorrencia);
            }
        

            if(!is_null($nrVitimaParteAtingida)) {
                $this->comunicadoAcidenteTrabalhoRepository->deleteParteAtingida( $nrVitimaParteAtingida, $row['NRORG'], $nrOcorrencia, $nrVitima );
            }   

            if(!is_null($nrVitima)) {
                $deleteVitima = $this->comunicadoAcidenteTrabalhoRepository->deleteVitima($nrVitima, $row['NRORG'], $nrOcorrencia);
            }     
    
 
            if($row['QTVITIMASOCORRE']) {
                $qtVítimasInt = (int)$row['QTVITIMASOCORRE'];

                if($qtVítimasInt === 1) {
                    $deleteOcorrenciaCAT = $this->comunicadoAcidenteTrabalhoRepository->deleteOcorrenciaCAT($nrOcorrencia, $row['NRORG']);
                }
            }
            $this->entityManager->commit();
            return $rowValidada;
        }  
        catch (\Exception $e) {
                $this->entityManager->rollback();
                throw $e;
            }

    }

    public function updateComunicadoAcidenteTrabalho($row) : array 
    {
        
           
        $this->entityManager->beginTransaction();
        
        try {
            $rowValidada = array();
            //$row['CDOPERADOR'] = intval($row['CDOPERADOR']) ?? null;
            if( $row["dadosCAT"] ) {
                $nrOcorrencia = $row["dadosCAT"]['NROCORRENCIA'];
                $dtOcorrencia = $row["dadosCAT"]['DTOCORRENCIA'];
                $hrOcorrencia = $row["dadosCAT"]['HROCORRENCIA'];
                $row["dadosCAT"]['DTHROCORRENCIAFORMAT'] = $dtOcorrencia . ' ' . $hrOcorrencia . ':00';
                $updateOcorrenciaCAT = $this->comunicadoAcidenteTrabalhoRepository->updateOcorrenciaCAT($row["dadosCAT"], $row['NRORG'], $row['CDOPERADOR']);

            }
 
            if( $row["dadosVitima"] ) {
                $nrVitima = $row["dadosVitima"]['NRVITIMA'];

                $dtInicatend = $row["dadosVitima"]['DTINICATEND'] ?? null;
                $hrInicatend = $row["dadosVitima"]['HRINICATEND'] ?? null;
                $row["dadosVitima"]['DTHRINICATENDFORMAT'] = $dtInicatend . ' ' . $hrInicatend . ':00';
                

                if(!isset($row["dadosVitima"]['NRCEPENDERECO']) && empty(($row["dadosVitima"]['NRCEPENDERECO']))){
                    $row["dadosVitima"]['NRCEPENDERECO'] = null;
                 } else {
                    $row["dadosVitima"]['NRCEPENDERECO'] = str_replace(['-', '.'], "", $row["dadosVitima"]['NRCEPENDERECO']);
                 }
 
                 if(isset($row["dadosVitima"]['QTHRATEINICATEND']) && !empty(($row["dadosVitima"]['QTHRATEINICATEND']))) {
                     $row["dadosVitima"]['QTHRATEINICATEND'] = str_replace(':', '', $row["dadosVitima"]['QTHRATEINICATEND']);
                    // $row["dadosVitima"]['QTHRATEINICATEND'] = intval($row["dadosVitima"]['QTHRATEINICATEND']);
                 } else {
                     $row["dadosVitima"]['QTHRATEINICATEND'] = null;
                 }
 
                 
                 if(isset($row["dadosVitima"]['QTHRATENDIMENTO']) && !empty(($row["dadosVitima"]['QTHRATENDIMENTO']))) {
                     $row["dadosVitima"]['QTHRATENDIMENTO'] = str_replace(':', '', $row["dadosVitima"]['QTHRATENDIMENTO']);
                    // $row["dadosVitima"]['QTHRATENDIMENTO'] = intval($row["dadosVitima"]['QTHRATENDIMENTO']);
                 } else {
                     $row["dadosVitima"]['QTHRATENDIMENTO'] = null;
                 }
           
                 if(isset($row["dadosVitima"]['QTHRAPOSINICTRAB']) && !empty(($row["dadosVitima"]['QTHRAPOSINICTRAB']))) {
                     $row["dadosVitima"]['QTHRAPOSINICTRAB'] = str_replace(':', '', $row["dadosVitima"]['QTHRAPOSINICTRAB']);
                    // $row["dadosVitima"]['QTHRAPOSINICTRAB'] = intval($row["dadosVitima"]['QTHRAPOSINICTRAB']);
                 } else {
                     $row["dadosVitima"]['QTHRAPOSINICTRAB'] = null;
                 }
                
                $dtFimcatend = $row["dadosVitima"]['DTFIMATEND'] ?? null;
                $hrFimcatend = $row["dadosVitima"]['HRFIMCATEND'] ?? null;

                if(!is_null($hrFimcatend) && !is_null($dtFimcatend)) {
                    $row["dadosVitima"]['DTHRFIMATENDFORMAT'] = $dtFimcatend . ' ' . $hrFimcatend . ':00';
                }
                
                if(!isset($row["dadosVitima"]['IDINTERNACAO']) || $row["dadosVitima"]['IDINTERNACAO'] == false) {
                    $row["dadosVitima"]['IDINTERNACAO'] = 'N';
                }

                if(!isset($row["dadosVitima"]['IDAFASTAMENTO']) || $row["dadosVitima"]['IDAFASTAMENTO'] == false) {
                    $row["dadosVitima"]['IDAFASTAMENTO'] = 'N';
                }

                $updateVitima = $this->comunicadoAcidenteTrabalhoRepository->updateVitima($row["dadosVitima"], $row['NRORG'], $row["dadosCAT"], $nrOcorrencia, $row['CDOPERADOR']);
            }

            if( $row["dadosParteAtingida"] ) {
                $nrVitimaParteAtingida = $row["dadosParteAtingida"]['NRVITPARTEATING'];
                if(is_null($nrVitimaParteAtingida)) {
                    $this->comunicadoAcidenteTrabalhoRepository->setParteAtingida( $row["dadosParteAtingida"], $row['NRORG'], $nrOcorrencia, $nrVitima, $row['CDOPERADOR']);
                } else {
                    $this->comunicadoAcidenteTrabalhoRepository->updateParteAtingida( $row["dadosParteAtingida"], $row['NRORG'], $nrOcorrencia, $nrVitima, $row['CDOPERADOR'] );
                }
            }
        
            if( $row["dadosFichaMedica"] ) {
                $nrFichaMedica = $row["dadosFichaMedica"]['NRFICHAMEDICA'];
               
                if(is_null($nrFichaMedica)) {
                    $nrFichaMedica = $this->comunicadoAcidenteTrabalhoRepository->setFichaMedica($row["dadosFichaMedica"], $row['NRORG'], $row["dadosVitima"], $nrOcorrencia, $row['CDOPERADOR']);
                } else {
                    $updateFichaMedica = $this->comunicadoAcidenteTrabalhoRepository->updateFichaMedica($row["dadosFichaMedica"], $row['NRORG'], $row["dadosVitima"], $nrOcorrencia, $row['CDOPERADOR']);
                }
        
            }
    
            
            if( $row["dadosDoenca"] ) {
                $nrDoencaFichaMedica= $row["dadosDoenca"]['NRDOENCAFICHAMEDICA'];
                if (strlen($row["dadosDoenca"]["DSDOENCAFICHAMEDICA"]) > 100) {
                    $row["dadosDoenca"]["DSDOENCAFICHAMEDICA"] = substr($row["dadosDoenca"]["DSDOENCAFICHAMEDICA"], 0, 100);
                }

                if(is_null($nrDoencaFichaMedica)) {
                    $this->comunicadoAcidenteTrabalhoRepository->setDoenca($row["dadosDoenca"],$row['NRORG'],  $nrFichaMedica, $row['CDOPERADOR']);       
                } else {
                    $this->comunicadoAcidenteTrabalhoRepository->updateDoenca($row["dadosDoenca"],$row['NRORG'],  $nrFichaMedica, $row['CDOPERADOR']);   
                }
                         
            }
    
    
            $this->entityManager->commit();
            return $rowValidada;
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    private function verificaPerfilAcesso($row)
    {
        $perfilSesmt = null;
        $nrEstruturasString = null;

        $perfilSesmt = $this->ocorrenciaRepository->verificaPerfilAcessoSESMT($row['NRORG'], $row['CDOPERADOR']);
       
        if(!empty($perfilSesmt)) {
            $row['NRESTRUTGEREN'] = null;
            return $row;
        } else {
            if ($row['NRESTRUTURAM'] !== "-1") {
              
                $nrEstruturas = $this->estruturaService->getTodasEstruturasInferiores($row['NRESTRUTURAM'], true);
                $nrEstruturasString = ArrayUtil::toStringSQL($nrEstruturas);
                $row['NRESTRUTGEREN'] = $nrEstruturasString;
                return $row;
            }
            $row['NRESTRUTGEREN'] = null;
            return $row;
        }

        return $row;
    }

    public function getFonteGeradora() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        $fonteGeradora = $this->comunicadoAcidenteTrabalhoRepository->getFonteGeradora($params);

        return $fonteGeradora;
    }

    public function getClassificacaoOcorrencia() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        $classificacaoOcorrencia = $this->comunicadoAcidenteTrabalhoRepository->getClassificacaoOcorrencia($params);
        return $classificacaoOcorrencia;
    }

    public function getGravidadeOcorrencia() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getGravidadeOcorrencia($params);
    }

    public function getInfluenciaGeral() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getInfluenciaGeral($params);
    }

    public function getAgenteCausadorAcidTrab() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getAgenteCausadorAcidTrab($params);
    }

    public function getNaturezaExame() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getNaturezaExame($params);
    }

    public function getTipoLocalCat() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getTipoLocalCat($params);
    }

    public function getNaturezaOcorrencia() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getNaturezaOcorrencia($params);
    }

    public function getAgenteCausador() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getAgenteCausador($params);
    }

    public function getParteAtingida() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getParteAtingida($params);
    }

    public function getMotivoAusencia() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getMotivoAusencia($params);
    }

    public function getQueixa() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getQueixa($params);
    }

    public function getResultadoExame() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getResultadoExame($params);
    }

    public function getSituacao() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();
        $dtMesCompetencia = $this->environment->getDtmescomptencDiaCorrente();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg,
            'P_DTEFETIVA'       => $dtMesCompetencia,
            'P_ATIVO'           => 'S'
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getSituacao($params);
    }

    public function getProximaSituacao() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();
        $dtMesCompetencia = $this->environment->getDtmescomptencDiaCorrente();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg,
            'P_DTEFETIVA'       => $dtMesCompetencia,
            'P_ATIVO'           => 'S'
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getProximaSituacao($params);
    }

    public function getCID() : array {

        return $this->comunicadoAcidenteTrabalhoRepository->getCID();
    }  

    public function getControleapt() : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRORG'           => $nrOrg
        ];

        return $this->comunicadoAcidenteTrabalhoRepository->getControleapt($params);
    }  
}