<?php

namespace Ems\Services;

use Ems\Repository\{
    ReconhecimentoFacialRepository
};
use Ems\Util\{
    Base64Util,
    ExpectedException,
    RequestUtils,
    Utils
};
use GuzzleHttp\Client;
use Util\{
    Environment,
    NovoCodigo,
    DateUtil
};
use Ems\Services\{
    ParceiroNegocioService,
};
use EMS\Util\Utilities;


class ReconhecimentoFacialService {
    /** @var Environment */
    protected $environment;

    /** @var Client */
    protected $http;

    protected $accountInfo = null;

    /** @var string */
    protected $reconhecimentoFacialUrl = null;

    /** @var ReconhecimentoFacialRepository */
    protected $reconhecimentoFacialRepository;

    /** @var ParceiroNegocioService */
    protected $parceiroNegocioService;


    /** @var Utilities */
    protected $utilities;

    public function __construct(
        Environment                    $environment,
        string                         $reconhecimentoFacialUrl,
        ReconhecimentoFacialRepository $reconhecimentoFacialRepository,
        ParceiroNegocioService         $parceiroNegocioService
    ) {
        $this->environment                    = $environment;
        $this->reconhecimentoFacialUrl        = $reconhecimentoFacialUrl;
        $this->reconhecimentoFacialRepository = $reconhecimentoFacialRepository;
        $this->parceiroNegocioService         = $parceiroNegocioService;

        $nrOrg = $this->environment->getNrOrg();

        if (!$nrOrg) {
            $this->setNrOrgFromHeader();
        }

        $this->utilities = Utils::getInstance('Utilities');
    }


    public function getUri(
        string $route
    ): string {
        $uri = $this->reconhecimentoFacialUrl . $route;
        return $uri;
    }

    public function helloWorld(): array {

        $uri = $this->getUri('helloWorld');

        $headers = [
            'Content-Type' => 'application/json'
        ];

        $body = [];

        $responseBody = RequestUtils::request($uri, $body, 'GET', $headers);
        

        if (!$responseBody) {
            throw new ExpectedException('Não foi possível fazer o upload do arquivo no Certisign!');
        }

        return $responseBody;
    }

    public function encodaImagem(string $base64Image1) {

        $uri = $this->getUri('encoda-imagem/');

        // Decodificar a string Base64 para obter os dados binários da imagem
        $imageData = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '', $base64Image1));

        // Criar um cliente GuzzleHttp
        $client = new Client();

        // Enviar a requisição usando o cliente GuzzleHttp
        $response = $client->request('POST', $uri, [
            'multipart' => [
                [
                    'name' => 'arquivo',
                    'contents' => $imageData,
                    'filename' => 'image.jpg' // Nome do arquivo, você pode ajustar conforme necessário
                ]
            ]
        ]);

        $content = $response->getBody()->getContents();
        

        if (!$content) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        $response = json_decode($content);

        if(!$response->resultado || $response->resultado == false) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        return $response->resultado;
    }

    public function verificaRostoEncodaECompara(string $base64Image1, string $base64Image2) {

        $uri = $this->getUri('verifica-rosto-encoda-compara/');

        // Decodificar a string Base64 para obter os dados binários da imagem
        $imageData1 = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '', $base64Image1));
        $imageData2 = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '', $base64Image2));


        // Criar um cliente GuzzleHttp
        $client = new Client();

        // Enviar a requisição usando o cliente GuzzleHttp
        $response = $client->request('POST', $uri, [
            'multipart' => [
                [
                    'name' => 'arquivo1',
                    'contents' => $imageData1,
                    'filename' => 'image.jpg' // Nome do arquivo, você pode ajustar conforme necessário
                ],
                [
                    'name' => 'arquivo2',
                    'contents' => $imageData2,
                    'filename' => 'image2.jpg' // Nome do arquivo, você pode ajustar conforme necessário
                ]
            ]
        ]);


        $content = $response->getBody()->getContents();
    

        if (!$content) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        $response = json_decode($content);

        if(!$response->resultado) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        return $response;
    }

    public function saveHashFacial(string $nrparcnegocio, string $base64Image) {
        $nrOrg = $this->environment->getNrOrg();

        $hashContent = $this->encodaImagem($base64Image);

        $hash = implode(',', $hashContent);

        $cdOperador = (string) $this->environment->getCdOperador();
        $params = [];

        $params['NRORG']           = $row['NRORG'] ?? $nrOrg;
        $params['NRFACEID']        = NovoCodigo::geraCodigo($nrOrg, 'GPE_FACEID', 1, 12, true, false);
        $params['NRPARCNEGOCIO']   = $nrparcnegocio;
        $params['HASHFACIAL']      = $hash;
        $params['IDATIVO']         = $row['IDATIVO'] ?? 'S';
        $params['NRORGINCLUSAO']   = $row['NRORGINCLUSAO'] ?? $nrOrg;
        $params['DTINCLUSAO']      = $row['DTINCLUSAO'] ?? date('d/m/Y');
        $params['CDOPERINCLUSAO']  = $row['CDOPERINCLUSAO'] ?? $cdOperador;
        $params['NRORGULTATU']     = $row['NRORGULTATU'] ?? null;
        $params['DTULTATU']        = $row['DTULTATU'] ?? null;
        $params['CDOPERULTATU']    = $row['CDOPERULTATU'] ?? null;

        $this->reconhecimentoFacialRepository->saveHashFacial($params);

        return true;
    }

    public function updateHashFacial($nrfaceid, string $nrparcnegocio, string $base64Image) {
        $nrOrg = $this->environment->getNrOrg();

        $hashContent = $this->encodaImagem($base64Image);

        $hash = implode(',', $hashContent);

        $cdOperador = (string) $this->environment->getCdOperador();
        $params = [];

        $params['P_NRFACEID']        = $nrfaceid;
        $params['P_NRPARCNEGOCIO']   = $nrparcnegocio;
        $params['P_NRORG']           = $row['NRORG'] ?? $nrOrg;
        $params['P_HASHFACIAL']      = $hash;
        $params['P_NRORGULTATU']     = $row['NRORGULTATU'] ?? $nrOrg;
        $params['P_DTULTATU']        = $row['DTULTATU'] ?? date('d/m/Y');
        $params['P_CDOPERULTATU']    = $row['CDOPERULTATU'] ?? $cdOperador;

        $this->reconhecimentoFacialRepository->updateHashFacial($params);

        return true;
    }

    public function deleteHashFacial($nrfaceid, string $nrparcnegocio) {
        $nrOrg = $this->environment->getNrOrg();

        $params = [];

        $params['P_NRFACEID']        = $nrfaceid;
        $params['P_NRPARCNEGOCIO']   = $nrparcnegocio;
        $params['P_NRORG']           = $row['NRORG'] ?? $nrOrg;

        $this->reconhecimentoFacialRepository->deleteHashFacial($params);

        return true;
    }

    public function reconhecimentoFacial(string $base64Image, string $hashConhecidos) {
        $uri = $this->getUri('verifica-rosto-compara-com-hashs-conhecidos/');

        // Decodificar a string Base64 para obter os dados binários da imagem
        $imageData = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '', $base64Image));

        // Criar um cliente GuzzleHttp
        $client = new Client();

        // Enviar a requisição usando o cliente GuzzleHttp
        $response = $client->request('POST', $uri, [
            'multipart' => [
                [
                    'name' => 'hashsConhecidos',
                    'contents' => $hashConhecidos
                ],
                [
                    'name' => 'arquivo',
                    'contents' => $imageData,
                    'filename' => 'image.jpg'
                ]
            ]
        ]);

        $content = $response->getBody()->getContents();


        if (!$content) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        $response = json_decode($content);

        if(!$response->resultado) {
            throw new ExpectedException('Não foi encontrado resultado!');
        }

        return $response;
    }

    public function getBiometriasVinculo(string $nrparcnegocio) {
        $nrOrg = $this->environment->getNrOrg();

        $biometrias = $this->reconhecimentoFacialRepository->getBiometriasVinculo($nrOrg, $nrparcnegocio);

        return $biometrias;
    }

}