<?php
namespace Eso\Repository\Esocial;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use Util\Environment;
use Ems\Util\Utils;

class S2210Repository {

    protected  $connection;

    public function __construct(EntityManager $entityManager, Environment $environment) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
        $this->environment = $environment;
    }
    
    public function getItensParaEnvioS2210($params) {
        $sql = <<<SQL
SELECT VI.NRVITIMA as NRCHAVE,
       VH.NRVINCULOM,
       'I' as IDOPERACAO,
       OC.DTHROCORRENCIA as DTMESCOMPETENC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT * FROM(SELECT H1.DTMESCOMPETENC FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  ORDER BY H1.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  JOIN GPE_PESSOA PE ON PE.NRORG = VM.NRORG
                    AND PE.NRPESSOA = VM.NRPESSOA
  JOIN SST_VITIMA VI ON VI.NRPARCNEGOCIO = PE.NRPARCNEGOCIO 
                    AND VI.NRORG = PE.NRORG
  /*Comunicação de Acidente de Trabalho.*/
  JOIN SST_OCORRENCIA OC ON OC.NRORG = VI.NRORG
                        AND OC.NROCORRENCIA = VI.NROCORRENCIA
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-2210'
               /*VERIFICA EMPRESAS DO MESMO GRUPO - CNPJ RAIZ*/
               JOIN ESTRUTURAH EVH ON EVH.NRORG = EC.NRORG
                                  AND EVH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(REPLACE(REPLACE(REPLACE(EVH.CDCNPJESTRUT,'.'),'/'),'-'),1,8) = SUBSTR(REPLACE(REPLACE(REPLACE(:P_CDCNPJEMPREGADOR,'.'),'/'),'-'),1,8)
                                  AND EVH.DTMESCOMPETENC = (SELECT * FROM(SELECT H1.DTMESCOMPETENC FROM ESTRUTURAH H1
                                                             WHERE H1.NRORG = EVH.NRORG
                                                               AND H1.NRESTRUTURAM = EVH.NRESTRUTURAM
                                                               AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                               ORDER BY H1.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
              WHERE EC.NRORG = :P_NRORG
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO FOI EXCLUIDO*/
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = VI.NRVITIMA
 WHERE VM.NRORG = :P_NRORG 
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
   AND (VM.NRVINCULOM = :P_NRVINCULOM OR :P_NRVINCULOM IS NULL)
   AND (OC.DTHROCORRENCIA >= :P_DTREFNAOPERIOD OR :P_DTREFNAOPERIOD IS NULL)
 ORDER BY 1,4
SQL;
        $params = array(
            "P_NRORG" => $this->environment->getNrOrgTrab(),
            "P_DTMESCOMPETENC" =>  Utils::getParamters()->getDtmescomptencDiaCorrente(),
            "P_CDCNPJEMPREGADOR" => isset($params['CDCNPJEMPREGADOR']) ? $params['CDCNPJEMPREGADOR'] : null,
            "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
            "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
            //"P_NRVITIMA" => isset($params['NRVITIMA']) ? $params['NRVITIMA'] : null,
            "P_NRVINCULOM" => isset($params['NRVINCULOM']) ? $params['NRVINCULOM'] : null,
            "P_DTREFNAOPERIOD" => isset($params['DTREFNAOPERIOD']) ? $params['DTREFNAOPERIOD'] : null,
        );
        return $this->connection->fetchAll($sql, $params);
    }

    public function getDadosS2210($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            
            /* Se for retificação do evento utiliza a data de envio do original para considerar as mesmas situações da época do primeiro envio */
            $dataEnvioOrig = null;
            if ($parametros['IDOPERACAO'] == 'R') {
                $dataEnvioOrig = $parametros['DTRESPOSTAORIG'];
            }
            
            $dados = $this->getDadosPrincipais($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $dataHistorico, $dataEnvioOrig);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosPrincipais($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
/*getDadosS2210*/
SELECT VI.NRVITIMA CHAVE,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
           CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END AS nrInsc,           
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA,'.'),'-') AS cpfTrab,
       DECODE(VM.NRTIPOVINCULOM,1,NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM),'') AS matricula,
       DECODE(VM.NRTIPOVINCULOM,1,'',CE.CDESOCIAL) codCateg,
       --cat
       TO_CHAR(OC.DTHROCORRENCIA, 'YYYY-MM-DD') AS dtAcid,       
       TA.CDESOCIAL AS tpAcid,
       DECODE(TA.CDESOCIAL,2,'',TO_CHAR(OC.DTHROCORRENCIA, 'HH24MI')) AS hrAcid,
       VI.QTHRAPOSINICTRAB AS hrsTrabAntesAcid,
       VI.IDTIPOCAT AS tpCat,
       DECODE(VI.DTOBITO, NULL, 'N', 'S') AS indCatObito,
       TO_CHAR(VI.DTOBITO, 'YYYY-MM-DD') AS dtObito,
       VI.IDREGPOLICIAL AS indComunPolicia,
       SITG.CDESOCIAL AS codSitGeradora,
       1 AS iniciatCAT,
       OC.DSOBSERVACAO AS observacao,
       OC.DSOBSERVACAO AS obsCAT,
       TO_CHAR(VI.DTULTDIATRABALHADO, 'YYYY-MM-DD') AS ultDiaTrab,
       NVL(VI.IDAFASTAMENTO,'N') AS houveAfast,
       --localAcidente
       TLC.CDESOCIAL AS tpLocal,
       VI.DSLOCALCAT AS dscLocal,
       LG.CDESOCIAL AS tpLograd,
       NVL(VI.DSENDERECO, EP.DSENDERECO) AS dscLograd,
       NVL(VI.NRIMOVELENDERECO, EP.NRIMOVELENDERECO) AS nrLograd,
       SUBSTR(DECODE(VI.NRCEPENDERECO, NULL, EP.DSCOMPLEENDERECO, VI.DSCOMPLEENDERECO), 0, 30) AS complemento,
       NVL(VI.NMBAIRROENDERECO, EP.NMBAIRROENDERECO) AS bairro,
       DECODE(TLC.CDESOCIAL,'2','',NVL(VI.NRCEPENDERECO, EP.NRCEPENDERECO)) AS cep,
       DECODE(TLC.CDESOCIAL,'2','',MU.CDMUNICIBGE) AS codMunic,
       DECODE(TLC.CDESOCIAL,'2','',NVL(VI.SGESTADO, EP.SGESTADO)) AS uf,
       DECODE(TLC.CDESOCIAL,'2',PA.CDESOCIAL,'') AS pais,
       DECODE(TLC.CDESOCIAL,'2',REPLACE(REPLACE(REPLACE(NVL(VI.NRCEPENDERECO, EP.NRCEPENDERECO),' '),'.'),'-'),'') AS codPostal,
       --ideLocalAcid
       DECODE(LENGTH(REPLACE(REPLACE(REPLACE(ECAT.CDCNPJESTRUT,'.'),'/'),'-')),14,1,11,2,'') AS ideLocalAcid_tpInsc,
       REPLACE(REPLACE(REPLACE(ECAT.CDCNPJESTRUT,'.'),'/'),'-') AS ideLocalAcid_nrInsc,
       --getDadosS2210parteAtingida
       --getDadosS2210agenteCausador       
       --atestado
       DECODE(FM.NRFICHAMEDICA,NULL,'',EHFM.CDFEDERALESTRUT) AS codCNES,
       DECODE(FM.NRFICHAMEDICA,NULL,'',TO_CHAR(VI.DTHRINICATEND, 'YYYY-MM-DD')) AS dtAtendimento,
       DECODE(FM.NRFICHAMEDICA,NULL,'',TO_CHAR(VI.DTHRINICATEND, 'HH24MI')) AS hrAtendimento,
       DECODE(FM.NRFICHAMEDICA,NULL,'',VI.IDINTERNACAO) AS indInternacao,
       DECODE(FM.NRFICHAMEDICA,NULL,'',TRUNC(FM.DTHRFIMAFASTAMENTO) - TRUNC(FM.DTHRINIAFASTAMENTO) + 1) durTrat,
       DECODE(FM.NRFICHAMEDICA,NULL,'',VI.IDAFASTAMENTO) AS indAfast,  
       DECODE(FM.NRFICHAMEDICA,NULL,'',NL.CDESOCIAL) AS dscLesao,
       DECODE(FM.NRFICHAMEDICA,NULL,'',N.NMNATUREZA) AS dscCompLesao,
       NULL diagProvavel,
       DECODE(FM.NRFICHAMEDICA,NULL,'',CID.CDCID) AS codCID,
       DECODE(FM.NRFICHAMEDICA,NULL,'',VI.DSOBSERVACAO) AS atestado_observacao,
       --emitente
       DECODE(FM.NRFICHAMEDICA,NULL,'',PHFM.NMPESSOA) AS nmEmit,
       DECODE(FM.NRFICHAMEDICA,NULL,'',DECODE(PHFM.NRCONSELHOREG,3,'1',9,'2',0)) ideOC,
       DECODE(FM.NRFICHAMEDICA,NULL,'',PHFM.NRINSCRCONSREG) AS nrOc,
       DECODE(FM.NRFICHAMEDICA,NULL,'',PHFM.SGUFCONSREG) AS ufOC,
       --catOrigem
       VIANT.DTCAT as dtCatOrig,
       VIANT.NRCAT AS nrCatOrig,
       VIANT.NRCAT AS nrRecCatOrig,
       VI.NRORG, VI.NRVITIMA
  FROM SST_VITIMA VI
  /*Comunicação de Acidente de Trabalho.*/
  JOIN SST_OCORRENCIA OC ON OC.NRORG = VI.NRORG
                        AND OC.NROCORRENCIA = VI.NROCORRENCIA
  JOIN SST_TIPOOCORRE TOC ON TOC.NRORG = OC.NRORG
                         AND TOC.NRTIPOOCORRE = OC.NRTIPOOCORRE  
  LEFT JOIN SST_SITUGERADORA SITG ON (SITG.NRORG = TOC.NRORG OR SITG.NRORG = 0)
                                 AND SITG.NRSITUGERADORA = TOC.NRSITUGERADORA
  LEFT JOIN SST_TIPOLOCALCAT TLC ON (TLC.NRORG = VI.NRORG OR TLC.NRORG = 0)
                                AND TLC.NRTIPOLOCALCAT = VI.NRTIPOLOCALCAT
  LEFT JOIN SST_NATUREZA N ON (N.NRORG = VI.NRORG OR N.NRORG = 0)
                          AND N.NRNATUREZA = VI.NRNATUREZA
  LEFT JOIN ESO_NATUREZALESAO NL ON (NL.NRORG = N.NRORG OR NL.NRORG = 0)
                                AND NL.NRNATUREZALESAO = N.NRNATUREZALESAO
  LEFT JOIN SST_CLASSIFICACAO CL ON CL.NRORG = OC.NRORG 
                                AND CL.NRCLASSIFICACAO = OC.NRCLASSIFICACAO
  LEFT JOIN SST_TIPOACIDENTE TA ON (TA.NRORG = CL.NRORG OR TA.NRORG = 0) 
                               AND TA.NRTIPOACIDENTE = CL.NRTIPOACIDENTE
  /*CAT ORIGEM*/
  LEFT JOIN SST_VITIMA VIANT ON VI.NRORG = VIANT.NRORG
                            AND VI.NRCATORIGEM = VIANT.NRCAT  
  /*Dados do Empregado*/
  JOIN PARCNEGOCIO PNV ON PNV.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
                      AND PNV.NRORG = VI.NRORG   
  JOIN GPE_PESSOA PE ON PNV.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
                    AND PNV.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT * FROM(SELECT GPE_PESSOAH.DTMESCOMPETENC FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG
                                                 ORDER BY GPE_PESSOAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  JOIN GPE_VINCULOM VM ON VM.NRORG = PE.NRORG
                      AND VM.NRPESSOA = PE.NRPESSOA
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT * FROM(SELECT GPE_VINCULOH.DTMESCOMPETENC FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG
                                                  ORDER BY GPE_VINCULOH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  
  /*TOMADOR */
  LEFT JOIN TIPOHIERARQORG TH ON (TH.NRORG = VH.NRORG OR TH.NRORG = 0)
                             AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                             AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
  LEFT JOIN HIERARQUIAORG HO ON HO.NRORG = VH.NRORG
                            AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
                            AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
                            AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                            AND (HO.DTFIMVIGENCIA IS NULL OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                            AND HO.DTINIVIGENCIA = (SELECT MAX(DTINIVIGENCIA)
                                                      FROM HIERARQUIAORG HI
                                                     WHERE HI.NRORG = HO.NRORG
                                                       AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
                                                       AND HI.NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
                                                       AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                                                       AND (HI.DTFIMVIGENCIA IS NULL OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                                                       AND HI.DTINIVIGENCIA <= :P_DTMESCOMPETENC)
                            AND (HO.DTFIMVIGENCIA >= LAST_DAY(:P_DTMESCOMPETENC) OR HO.DTFIMVIGENCIA IS NULL)
  
  /*LOCAL CAT */
  LEFT JOIN ESTRUTURAH ECAT ON ECAT.NRORG = OC.NRORG
                      AND ECAT.NRESTRUTURAM = DECODE(TLC.CDESOCIAL,'1', VH.NRESTRUTLEGAL, '2', VH.NRESTRUTLEGAL, '3', HO.NRESTRUTURAMSUP, OC.NRESTRUTURAM)
                      AND ECAT.DTMESCOMPETENC = (SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                  WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                    AND NRESTRUTURAM = ECAT.NRESTRUTURAM
                                                    AND NRORG = ECAT.NRORG
                                                    ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                            
  LEFT JOIN ENDERECOPARC EP ON EP.NRPARCNEGOCIO = ECAT.NRPARCNEGOCIO
                           AND EP.NRORG = ECAT.NRORG
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
  LEFT JOIN LOGRADOURO LG ON LG.CDLOGRADOURO = NVL(VI.CDLOGRADOURO, EP.CDLOGRADOURO)
  LEFT JOIN PAIS PA ON PA.CDPAIS = NVL(VI.CDPAIS, EP.CDPAIS)
  LEFT JOIN MUNICIPIO MU ON MU.CDPAIS = NVL(VI.CDPAIS, EP.CDPAIS)
                        AND MU.SGESTADO = NVL(VI.SGESTADO, EP.SGESTADO)
                        AND MU.CDMUNICIPIO = NVL(VI.CDMUNICIPIO, EP.CDMUNICIPIO)
  
  /*Ficha Medica*/
  LEFT JOIN SST_FICHAMEDICA FM ON FM.NRORG = VM.NRORG
                              AND FM.NRVINCULOM = VM.NRVINCULOM
                              AND FM.NROCORRENCIA = VI.NROCORRENCIA
  LEFT JOIN SST_DOENCAFICHAMEDICA DFM ON DFM.NRORG = FM.NRORG
                                     AND DFM.NRFICHAMEDICA = FM.NRFICHAMEDICA
  LEFT JOIN SST_CID CID ON CID.NRCID = DFM.NRCID 
  /*Responsavel Ficha Medica*/
  LEFT JOIN ESTRUTURAH EHFM ON EHFM.NRORG = FM.NRORG
                           AND EHFM.NRESTRUTURAM = FM.NRESTRUTURAM
                           AND EHFM.DTMESCOMPETENC = (SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                       WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                         AND NRESTRUTURAM = EHFM.NRESTRUTURAM
                                                         AND NRORG = EHFM.NRORG
                                                         ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  LEFT JOIN GPE_PESSOA PFM ON PFM.NRPARCNEGOCIO = FM.NRPARCNEGOCIO
                          AND PFM.NRORG = FM.NRORG
  LEFT JOIN GPE_PESSOAH PHFM ON PFM.NRPESSOA = PHFM.NRPESSOA
                            AND PFM.NRORG    = PHFM.NRORG
                            AND PHFM.NRCONSELHOREG IS NOT NULL
                            AND PHFM.DTMESCOMPETENC = (SELECT * FROM(SELECT GPE_PESSOAH.DTMESCOMPETENC FROM GPE_PESSOAH
                                                        WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                          AND GPE_PESSOAH.NRPESSOA = PHFM.NRPESSOA
                                                          AND GPE_PESSOAH.NRORG = PHFM.NRORG
                                                          ORDER BY GPE_PESSOAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  /*Empregador*/
  LEFT JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EMH.NRESTRUTURAM
                                                  AND NRORG = EMH.NRORG
                                                  ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
  LEFT JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE VI.NRORG = :P_NRORG
   AND VI.NRVITIMA = :P_NRCHAVE
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC)
SQL;
        $params = array(
            "P_NRORG" => $this->environment->getNrOrgTrab(),
            "P_DTMESCOMPETENC" =>  Utils::getParamters()->getDtmescomptencDiaCorrente(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_NRTIPOESTRUTGEREN" => $this->environment->getTipoEstruturaGerencialOrg(),
            "P_NRTIPOESTRUTOMADOR" => $this->environment->getTipoEstruturaTomadorOrg()
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2210parteAtingida($params) {
        $sql = <<<SQL
/*getDadosS2210parteAtingida*/
SELECT PAE.CDESOCIAL AS codParteAting,
       VPA.LATERALIDADE AS lateralidade,
       VPA.NRVITIMA
  FROM SST_VITIMAPARTEATINGIDA VPA
  JOIN SST_PARTEATINGIDA PA ON (PA.NRORG = VPA.NRORG OR PA.NRORG = 0)
                           AND PA.NRPARTEATINGIDA = VPA.NRPARTEATINGIDA
  JOIN SST_PARTATINGESOC PAE ON PA.NRPARTATINGESOC = PAE.NRPARTATINGESOC
                            AND (PAE.NRORG = PA.NRORG OR PAE.NRORG = 0)
 WHERE VPA.NRVITIMA = :P_NRVITIMA
   AND VPA.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $this->environment->getNrOrgTrab(),
            "P_NRVITIMA" => $params['NRVITIMA']
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2210agenteCausador($params) {
        $sql = <<<SQL
/*getDadosS2210agenteCausador*/
SELECT AC.CDESOCIAL codAgntCausador
  FROM SST_VITIMA VI
  LEFT JOIN SST_AGENTCAUSAD AC ON AC.NRAGENTCAUSAD = VI.NRAGENTCAUSAD
                              AND (AC.NRORG = VI.NRORG OR AC.NRORG = 0)
 WHERE VI.NRORG = :P_NRORG
   AND VI.NRVITIMA = :P_NRVITIMA
SQL;
        $params = array(
            "P_NRORG" => $this->environment->getNrOrgTrab(),
            "P_DTMESCOMPETENC" =>  Utils::getParamters()->getDtmescomptencDiaCorrente(),
            "P_NRVITIMA" => $params['NRVITIMA'],
        );
        return $this->connection->fetchAll($sql, $params);
    }

}