<?php
namespace Eso\Services;

use Util\Environment;
use Doctrine\ORM\EntityManager;
use Eso\Logic\ESocialLogic;
use Eso\Repository\ESocialRepository;
use Eso\Services\EsoSimplificadoService;
use Geral\Entity\GpevinculomEntity;
use Util\Builder\Template;
use Util\DateUtil;
use Util\FPA;
use Util\TkDI;
use Util\HCMParameters;
use Util\Messages;
use Util\MsgProcesso;
use Util\Repositories;
use Util\Util;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Ems\Util\Utils;

class ESocialService {

    const TPAMB_PROD = 1;
    const TPAMB_PROD_REST_REAL = 2;
    const TPAMB_PROD_REST_FICT = 3;
    
    const URL_PRODREST = 'https://webservices.producaorestrita.esocial.gov.br';
    const URL_ENVIO_PRODUCAO = 'https://webservices.envio.esocial.gov.br';
    const URL_CONSULTA_PRODUCAO = 'https://webservices.consulta.esocial.gov.br';
    const LOCATION_ENVIO = '/servicos/empregador/enviarloteeventos/WsEnviarLoteEventos.svc';
    const LOCATION_CONSULTA = '/servicos/empregador/consultarloteeventos/WsConsultarLoteEventos.svc';
    const FUNCTION_ENVIO = 'EnviarLoteEventos';
    const FUNCTION_CONSULTA = 'ConsultarLoteEventos';
    
    const IDSTATUS_PENDENTE = 'P';
    const IDSTATUS_ERRO_ENVIO = 'E';
    const IDSTATUS_PROCESSAMENTO = 'M';
    const IDSTATUS_ERRO_PROCESSAMENTO = 'R';
    const IDSTATUS_CONCLUIDO = 'C';
    const IDSTATUS_CONCLUIDO_ADVERTENCIA = 'A';

    /* Códigos de retorno do envio do lote */
    const CD_RET_LOTE_201 = '201';     // Lote recebido com sucesso
    const CD_RET_LOTE_202 = '202';     // Lote recebido com advertências
    const CD_RET_LOTE_301 = '301';     // Erro servidor eSocial
    const CD_RET_LOTE_401 = '401';     // Lote incorreto - Erro preenchimento
    const CD_RET_LOTE_402 = '402';     // Lote incorreto - Schema inválido
    const CD_RET_LOTE_403 = '403';     // Lote incorreto - Versão do schema não permitida
    const CD_RET_LOTE_404 = '404';     // Lote incorreto - Erro certificado
    const CD_RET_LOTE_405 = '405';     // Lote incorreto - Lote nulo ou vazio
    /* Códigos de retorno da consulta de processamento do lote */
    const CD_RET_CONS_101 = '101';     // Lote aguardando processamento
    const CD_RET_CONS_201 = '201';     // Lote Processado com Sucesso.
    const CD_RET_CONS_202 = '202';     // Lote Processado com Advertências.
    const CD_RET_CONS_301 = '301';     // Erro Servidor eSocial
    const CD_RET_CONS_401 = '401';     // Lote Incorreto - Erro preenchimento.
    const CD_RET_CONS_402 = '402';     // Lote Incorreto - Schema Inválido.
    const CD_RET_CONS_403 = '403';     // Lote Incorreto - Versão do Schema não permitida.
    const CD_RET_CONS_404 = '404';     // Lote Incorreto - Erro Certificado.
    const CD_RET_CONS_405 = '405';     // Lote Incorreto - Lote nulo ou vazio.
    const CD_RET_CONS_501 = '501';     // Solicitação de Consulta Incorreta -Erro Preenchimento.
    const CD_RET_CONS_502 = '502';     // Solicitação de Consulta Incorreta - Schema Inválido.
    const CD_RET_CONS_503 = '503';     // Solicitação de Consulta Incorreta - Versão do Schema Não Permitida.
    const CD_RET_CONS_504 = '504';     // Solicitação de Consulta Incorreta - Erro Certificado.
    const CD_RET_CONS_505 = '505';     // Solicitação de Consulta Incorreta - Consulta nula ou vazia.
    /* Códigos de retorno de processamento do evento */
    const CD_RET_EVEN_201 = '201';     // Sucesso
    const CD_RET_EVEN_202 = '202';     // Sucesso com advertência
    const CD_RET_EVEN_301 = '301';     // Erro Servidor
    const CD_RET_EVEN_401 = '401';     // Erro no conteúdo do evento
    const CD_RET_EVEN_402 = '402';     // Schema inválido
    const CD_RET_EVEN_403 = '403';     // Leiaute inválido
    const CD_RET_EVEN_404 = '404';     // Erro do certificado digital da assinatura do evento
    const CD_RET_EVEN_405 = '405';     // Erro na assinatura evento
    const CD_RET_EVEN_406 = '406';     // Evento não pertence ao grupo especificado no lote de eventos
    const CD_RET_EVEN_411 = '411';     // Assinante inválido

    const ERRO = 'Erro';
    const ADVERTENCIA = 'Advertência';

    private $_tempEsocialPath;

    private $_xmlTemplatesPath;
    private $_xsdTemplatesPath;
    private $_certificatesPath;
    private $_tempCertificatesPath;

    private $_tpInscTransmissor;
    private $_nrInscTransmissor;
    private $_tpInscEmpregador;
    private $_nrInscEmpregador;
    
    private $_certFile;
    private $_certPass;
    private $_certKeyFile;
    
    private $_wsLocation;
    private $_wsUri;
    private $_wsWsdl;
    private $_wsFuncion;
    
    private $_wsConsultaAction;
    private $_wsConsultaUrl;
    private $_wsConsultaWsdl;

    private $_xmlFilesPath;

    private $_arrXmlCaracter;
    private $_arrXmlEscape;

    private $_tpAmb;
    private $_procEmi;
    private $_verProc;

    private $_tipoOcorRetorno;
    
    private $_tagsTrad;
    private $_tagsOpc;
    private $_tagNivel;
    
    private $_vinculom;
    
    public $arrayMensagens = array(
    "HCM09000_ESO_CALLED_EVENTO_ERROR" => "Erro ao montar dados de envio para o evento informado",
    "HCM09000_ESO_CARGAINI_EXISTS_ERROR" => "Processo de carga inicial já realizado para a estrutura",
    "HCM09000_ESO_CERTIFICADO_NOT_FOUND_ERROR" => "Certificado do transmissor não encontrado. Favor carregar o certificado na tela 'Parametros do eSocial'.",
    "HCM09000_ESO_CERTIFICADO_NOT_OPEN_ERROR" => "Não foi possível ler o certificado do transmissor. Favor tentar novamente.",
    "HCM09000_ESO_CERTIFICADO_VALIDADE_ERROR" => "Certificado do transmissor com validade vencida. Favor carregar um novo certificado na tela 'Parametros do eSocial'.",
    "HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR" => "Não foram encontrados itens para filtro informado",
    "HCM09000_ESO_EXCLUSAO_ERROR" => "Não é possível excluir eventos que já foram enviados",
    "HCM09000_ESO_FILE_LOTE_NOT_FOUND_ERROR" => "Arquivo de lote não encontrado para envio",
    "HCM09000_ESO_GENERATE_CERT_KEY_ERROR" => "Certificado inválido ou senha inválida",
    "HCM09000_ESO_IDEVENTO_INVALID_ERROR" => "Evento com ID inválido. Favor verificar a inscrição do empregador e seu tipo (CNPJ ou CPF), e reenviar o evento",
    "HCM09000_ESO_INSCR_TRANSM_NOT_FOUND_ERROR" => "O responsável pela transmissão informado, não possui inscrição",
    "HCM09000_ESO_EVENTO_MATRIZ_ERROR" => "O evento só pode ser enviado por uma estrutura que possua um CNPJ Matriz",
    "HCM09000_ESO_LOTE_QTDE_ERROR" => "O lote pode ser composto, no máximo, por 50 eventos",
    "HCM09000_ESO_LOTE_STATUS_ERROR" => "O lote só pode ser transmitido com eventos pendentes",
    "HCM09000_ESO_LOTE_VAZIO_ERROR" => "Não foram encontrados dados para envio do lote",
    "HCM09000_ESO_PARAMETRO_NOT_FOUND_ERROR" => "Parâmetro do eSocial não encontrado para a estrutura",
    "HCM09000_ESO_PRODREST_OPER_ERROR" => "Operação válida somente para o ambiente de Produção Restrita",
    "HCM09000_ESO_SENHA_CERTIFICADO_NOT_FOUND_ERROR" => "Senha do certificado do transmissor não encontrada. Favor informar a senha na tela 'Parametros do eSocial'.",
    "HCM09000_ESO_TPINSCEMPREG_ERROR" => "Tipo de inscrição do empregador inválido. O empregador deve ser pessoa júridica ou pessoa física",
    "HCM09000_ESO_TPINSCTRANSM_ERROR" => "Tipo de inscrição do responsável pela transmissão inválido. O responsável deve ser pessoa júridica ou pessoa física",
    "HCM09000_ESO_UNIQUE_ENVIO_ERROR" => "Já existe envio para evento com mesmos parâmetros");

    public function __construct(EntityManager $entityManager, Environment $environment, 
                      EsoSimplificadoService $esoSimplificadoService, ESocialRepository $eSocialRepository) {
        $this->entityManager          = $entityManager;
        $this->environment            = $environment;
        $this->eSocialRepository      = $eSocialRepository;
        $this->esoSimplificadoService = $esoSimplificadoService;
        
        $this->tempEsocialPath = Util::getTempDirectory() . DIRECTORY_SEPARATOR . "esocial";
        $this->certificatesPath = Util::getFileServerUrl();
        $this->tempCertificatesPath = $this->tempEsocialPath . DIRECTORY_SEPARATOR . "certificates" . DIRECTORY_SEPARATOR .  $this->environment->getNrOrgTrab();


        $this->xmlFilesPath = $this->tempEsocialPath . DIRECTORY_SEPARATOR . "xmlFiles" . DIRECTORY_SEPARATOR .  $this->environment->getNrOrgTrab();


        $this->_arrXmlCaracter = array('>', '<', '&', '"', "'");
        $this->_arrXmlEscape = array('&gt;', '&lt;', '&amp;', '&quot;', '&#39');

        $this->_procEmi = 1;
        //$this->_verProc = $this->hcmParameters->getProjectVersion();

        $this->_tipoOcorRetorno = array(
            '1' => self::ERRO,
            '2' => self::ADVERTENCIA,
        );
            
        $this->_tagsTrad = array();
        $this->_tagsOpc = array();
        $tagsTrad = $this->eSocialRepository->getTagName($this->environment->getNrOrgPadrao() ? $this->environment->getNrorgPadrao() : 0);
        foreach ($tagsTrad as $tag) {
            $this->_tagsTrad[$tag['DSTAGNAME']] = $tag['DSTAGTRADUCAO'] != '' ?  $tag['DSTAGTRADUCAO'] : $tag['DSTAGNAME'];
            $cdOpcoes = $tag['DSCDOPCTAG'] ? explode(';', $tag['DSCDOPCTAG']) : null;
            $nmOpcoes = $tag['DSNMOPCTAG'] ? explode(';', $tag['DSNMOPCTAG']) : null;
            if($cdOpcoes){
                foreach($cdOpcoes as $index => $cdOpcao){
                    $this->_tagsOpc[$tag['DSTAGNAME']][$cdOpcao] = $nmOpcoes[$index];
                }
            }
        }
        
        // Variável temporária para gravar e ler os arquivos no servidor AWS para evitar tráfego com o FileServer.
        $this->filesDir = __DIR__ . "/../../../../../../../files/";
        $this->filesDirESocial = "/eSocial/";
        
        // Variável temporária para salvar log de execução do eSocial
        $this->logId = $this->environment->getNrOrgTrab() . '.' . $this->environment->getCdoperador() . '.' . DateUtil::getDataAtual()->format('YmdHis');
        $this->logContent = "========================================= Start log at " . DateUtil::getDataAtual()->format('Y/m/d H:i:s') . " [" . $this->environment->getNrOrgTrab() . "]\n";
        $this->gravaLog = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            buscavalor($this->environment->getNrOrgTrab(), $this->environment->getNrorgPadrao(),  Utils::getParamters()->getDtmescomptencDiaCorrente(), 'ESOCIAL_GRAVA_LOG');
    }

    /**
     * Retorna todas as versões do eSocial disponíveis na tabela ESO_EVENTO
     * @param $idativo
     * @return array
     */
    public function getVersoesESocial($idativo) {
        return $this->eSocialRepository->getVersoesESocial($idativo);
    }
    
    /**
     * Atualiza o idativo do envio selecionado
     * @param $nrorg
     * @param $nrestruturam
     * @param $nrenvio
     * @return 
     */
    public function inativaEvento($nrorg, $nrestruturam, $nrenvio){
        return $this->eSocialRepository->inativaEvento($nrorg, $nrestruturam, $nrenvio);
    }
        
    /**
     * Retorna todas as estruturas legais da organização com os parametros do esocial
     * @param $nrorg
     * @param $dtmescompetenc
     * @param $nrtipoestrutlegal
     * @return array
     */
    public function getEstruturasESocial($nrorg, $dtmescompetenc, $nrtipoestrutlegal, $idGrupo, $conditions) {
        if(is_array($idGrupo) && $idGrupo[0] == 'P'){
            $idGrupo = 'P';
        }
        return $this->eSocialRepository->getEstruturasESocial($nrorg, $dtmescompetenc, $nrtipoestrutlegal, $idGrupo, $conditions);
    }
    
    /**
     * Retorna o evento do eSocial
     * @param $nmevento
     * @param $dsversao
     * @return object
     */
    public function getEvento($nrevento) {
        try {
            return $this->entityManager->getRepository(Repositories::ESO_EVENTO)->findOneBy(array('nrevento' => $nrevento));
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Retorna o evento do eSocial
     * @param $nmevento
     * @param $dsversao
     * @return object
     */
    public function getEventoPorNomeVersao($nmevento, $dsversao) {
        try {
            return $this->entityManager->getRepository(Repositories::ESO_EVENTO)->findOneBy(array('nmevento' => $nmevento, 'dsversao' => $dsversao));
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function envioEsocialDescentralizado($dataSet, $response){
        try{
            $nrorg = $this->environment->getNrOrgTrab();
            $dtmescompetenc = array_key_exists('DTMESCOMPETENC', $dataSet) ? $dataSet['DTMESCOMPETENC'] :  Utils::getParamters()->getDtmescomptencDiaCorrente();
            $nrtipoestrutlegal = $this->environment->getTipoEstruturaLegalOrg();
            $paramESocial = null;
            $eventosLote = array();
            $msgValidacao = array();
            $idGrupo = null;
            $dsVersao = null;

            if(array_key_exists('NRVINCULOM', $dataSet) && !empty($dataSet['NRVINCULOM'])){
                
                if($dataSet['NMEVENTO'] == 'S-2190') {
                    $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOH)->retornaUltimoHistoricoCompetencia($nrorg, $dataSet['NRVINCULOM'], "01/01/3000");
                } else {
                    $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOH)->retornaUltimoHistoricoCompetencia($nrorg, $dataSet['NRVINCULOM'], $dtmescompetenc);
                }
                
             
                $dataSet['NRESTRUTURAM'] = is_object($vinculo) ? $vinculo->getNrestrutlegal() : (isset($dataSet['NRESTRUTURAM']) ?  $dataSet['NRESTRUTURAM'] : null);
                $objEstrutMatriz = $this->entityManager->getRepository(Repositories::ESTRUTURAH)->retornaEstruturaMatrizPorEstruturaLegal($nrorg, $dataSet['NRESTRUTURAM'], $nrtipoestrutlegal, $dtmescompetenc);

                $paramESocial = $this->getParamESocial($objEstrutMatriz ? $objEstrutMatriz[0]->getNrestruturam() : $dataSet['NRESTRUTURAM']);
              
                $dataSet['PARENT'] = $objEstrutMatriz ? $objEstrutMatriz[1]->getCdcnpjestrut() : null;
                $dataSet['NRESTRUTEMPREGADOR'] = $objEstrutMatriz ? $objEstrutMatriz[0]->getNrestruturam() : $dataSet['NRESTRUTURAM'];
                
                $msgProcesso = MsgProcesso::getInstance($this->environment->getNrOrgTrab(), $this->environment->getCdoperador(), $dataSet['NRESTRUTURAM']);
                // Verifica se a estrutura tem parâmetro do eSocial
                if (empty($paramESocial)) {
                   MsgProcesso::getInstance()->addError($this->arrayMensagens['HCM09000_ESO_PARAMETRO_NOT_FOUND_ERROR']);
                }else{
                    if ($paramESocial['DSVERSAO'] == "S-1.0" || $paramESocial['DSVERSAO'] == "S-1.1" || $paramESocial['DSVERSAO'] == "S-1.2") {
                        $dataSet['NRTPAMBIENTE'] = $paramESocial['NRTPAMBIENTE'];
                        $dataSet['CDCNPJEMPREGADOR'] = $paramESocial['CDCNPJESTRUT'];
                        $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($dataSet['NMEVENTO'], null, $dataSet);
                        if (empty($arrItens)) {
                            MsgProcesso::getInstance()->addError($this->arrayMensagens['HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR']);
                        } else {
                            $logic = new ESocialLogic($this->entityManager, $this->environment,  Utils::getParamters()->getDtmescomptencDiaCorrente(), $paramESocial['NRESTRUTURAM'], $paramESocial['NRTPAMBIENTE']);
                            foreach($arrItens as $item) {
   
                                if($dataSet['NRCHAVE'] == $item['NRCHAVE']) {
                                    //$dataSet['NRCHAVE'] = $item['NRCHAVE'];
                                    $dataSet['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : null;
                                    $dataSet['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                                    $dataSet['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
                                    
                                    try {
                                        $this->esoSimplificadoService->beforeInsertNaoPeriodico(
                                            $dataSet['NRORG'], $dataSet['NRTPAMBIENTE'], $dataSet['NRESTRUTURAM'], $dataSet['CDCNPJEMPREGADOR'], $vinculo->getNrvinculom(), $item['DTMESCOMPETENC'], $dataSet['NMEVENTO'], $item['NRCHAVE'], $dataSet['NRTABELA'], $item['IDOPERACAO']
                                        );
                                        $envio = $logic->novoEsoNaoPeriodico($dataSet['NRESTRUTEMPREGADOR'], $vinculo->getNrvinculom(), $dataSet['NMEVENTO'], $paramESocial['DSVERSAO'], $dataSet['NRTPAMBIENTE'], $item['NRCHAVE'], $item['DTMESCOMPETENC'], $item['IDOPERACAO'], $dataSet['NRTABELA']);
                                        $this->entityManager->flush();
                                    } catch(\Exception $e) {
                                        if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                            if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                                MsgProcesso::getInstance()->addError($this->arrayMensagens['HCM09000_ESO_UNIQUE_ENVIO_ERROR']);
                                            } else {
                                                MsgProcesso::getInstance()->addError($e->getMessage());
                                                //$response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage()), \Zeedhi\Framework\DTO\Response\Message::TYPE_WARNING);
                                            }
                                            continue;
                                        } else {
                                            throw $e;
                                        }
                                    }
                                    
                                    if ($envio) {
                                        try{
                                            $itemEnvio = $envio->toArray();
                                            $itemEnvio['DTMESCOMPETENC'] = is_object($item['DTMESCOMPETENC']) ? $item['DTMESCOMPETENC']->format('d/m/Y H:i:s') : $item['DTMESCOMPETENC'];
                                            $itemEnvio['DSVERSAO'] = str_replace('.','-',$paramESocial['DSVERSAO']);
                                            $itemEnvio['NRINSCRICAOPARC'] = $dataSet['CDCNPJEMPREGADOR'];
                                            $itemEnvio['NRTPAMBIENTE'] = $paramESocial['NRTPAMBIENTE'];
                                            $itemEnvio['DTINCLUSAO'] = $this->environment->getDtmescomptencDiaCorrente();
                                            $itemEnvio['DTULTATU'] = $this->environment->getDtmescomptencDiaCorrente();
                                            $itemEnvio['NRORGULTATU'] = $this->environment->getNrOrgTrab();
                                            $itemEnvio['NRORGINCLUSAO'] = $this->environment->getNrOrgTrab();
                                            $itemEnvio['CDOPERULTATU'] = $this->environment->getCdoperador();
                                            $itemEnvio['CDOPERINCLUSAO'] = $this->environment->getCdoperador();
                                            
                                            $processoAdmissao = isset($dataSet['IDPROCESSOADMISSAO']) && $dataSet['IDPROCESSOADMISSAO'] === 'S';
                                            if ($processoAdmissao) {
                                                $msgRetorno = $logic->enviarEventoNaoPeriodico($itemEnvio, false, true);
                                            } else {
                                                $msgRetorno = $logic->enviarEventoNaoPeriodico($itemEnvio, true);
                                            }
                                            
                                            MsgProcesso::getInstance()->addMessage($msgRetorno);
                                            
                                            $this->entityManager->flush();
                                        } catch(\Exception $e) {
                                            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                                if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                                    MsgProcesso::getInstance()->addError($this->arrayMensagens['HCM09000_ESO_UNIQUE_ENVIO_ERROR']);
                                                } else {
                                                    MsgProcesso::getInstance()->addError($e->getMessage());
                                                    //$response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage()), \Zeedhi\Framework\DTO\Response\Message::TYPE_WARNING);
                                                }
                                                continue;
                                            } else {
                                                throw $e;
                                            }
                                        }
                                    }
                                }                         
                            }
                        }
                    }
                }
                
                foreach ($msgProcesso->getMessages() as $msg) {
                    $msgValidacao[] = array(
                        'NMEVENTO' => $dataSet['NMEVENTO'],
                        'NRCHAVE' => $dataSet['NRCHAVE'],
                        'MSG' => $msg['MSG'],
                        'TYPE' => $msg['TYPE'],
                    );
                }
                $msgProcesso->clear();
                unset($msgProcesso);
                
                if (count($msgValidacao) > 0) {
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', $msgValidacao));
                } elseif ($msgRetorno) {
                    if(!$processoAdmissao) {
                        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', [['MSG' => $msgRetorno, 'TYPE' => 'S', 'NRCHAVE' => $dataSet['NRCHAVE'],  'NMEVENTO' => $dataSet['NMEVENTO']]]));
                    } else {
                        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', [['MSG' => $msgRetorno, 'TYPE' => 'S']]));
                    }
                } else {
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', [['MSG' => "Serviço de envio não disponível", 'TYPE' => 'E']]));
                }
            }else{
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', [['MSG' => "Vínculo não identificado.", 'TYPE' => 'E']]));
            }
            
        }catch(\Exception $e) {
            if(array_key_exists($e->getMessage(), $this->arrayMensagens)){
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retornoEsocial', [['MSG' => $this->arrayMensagens[$e->getMessage()], 'TYPE' => 'S']]));
            }else{
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage() . "[" . $e->getTraceAsString() . "]", $e->getCode()));
            }
        }
    }


    /**
     * @param $nrestruturam
     * @return array
     * @throws \Exception
     */
    public function getParamESocial($nrestruturam) {
        try {
            //@todo validar tipo de inscrição CNPJ/CPF e inscrição com caracteres inválidos
            $parametro = $this->eSocialRepository->getParamESocial($nrestruturam);
            if (!empty($parametro)) {
                if ($parametro['TPINSCRICAOEMP'] != '1' && $parametro['TPINSCRICAOEMP'] != '2') {
                    throw new \Exception(Messages::HCM09000_ESO_TPINSCEMPREG_ERROR,Messages::ERROR_MESSAGE_CODE);
                }
                if ($parametro['TPINSCRICAOPARC'] != '1' && $parametro['TPINSCRICAOPARC'] != '2') {
                    throw new \Exception(Messages::HCM09000_ESO_TPINSCTRANSM_ERROR,Messages::ERROR_MESSAGE_CODE);
                }
            }
            return $parametro;
        } catch(\Exception $e) {
            throw $e;
        }
    }
}