<?php
namespace Eso\Services;

use Util\Environment;
use Doctrine\ORM\EntityManager;
use HCM\Util\DateUtil;
use Util\Messages;
use Util\NovoCodigo;
use Util\Repositories;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO;
use Ems\Util\Utils;

class EsoSimplificadoService {

    /* Grupos de Eventos do eSocial */
    const IDGRUPO_CADASTRO = 'C';
    const IDGRUPO_INICIAL = 'I';
    const IDGRUPO_TABELAS = 'T';
    const IDGRUPO_NAOPERIODICO = 'N';
    const IDGRUPO_PERIODICO = 'P';

    public function __construct(EntityManager $entityManager, Environment $environment) {
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->eSocialRepository = new \Eso\Repository\ESocialRepository($this->entityManager->getConnection(), $this->entityManager, $this->environment);
    }

    public function getItensParaEnvioEvento($nmevento, $idgrupo, $params = array(), $jenkins = false) {
        try {
            $repository = $this->getRepository(str_replace('-','',$nmevento));
            $method = 'getItensParaEnvio' . str_replace('-','',$nmevento);

            if (method_exists($repository, $method)) {
                $estruturas = null;
                $itens = array();

                if ($nmevento != 'S-1000' && $nmevento != 'S-1005' && $nmevento != 'S-1010' && $nmevento != 'S-2299' && $nmevento != 'S-2399') {
                    // Busca todas estruturas legais com o mesmo raiz do CNPJ (Matriz e filiais) para buscar itens do evento em todo empregador
                    $estruturas = $this->entityManager->getRepository(Repositories::ESTRUTURAH)->retornaEstruturasPorRaizCnpj(
                        $this->environment->getNrOrgTrab(), $params['CDCNPJEMPREGADOR'], $this->environment->getTipoEstruturaLegalOrg(), Utils::getParamters()->getDtmescomptencDiaCorrente()
                    );
                } else {
                    $estruturas = null;
                }

                if (empty($estruturas) || !$estruturas) {
                    $itens = $repository->$method($params);
                } else {
                    // Alteração para fazer a inserção para a matriz e suas filiais conforme o cnpj da estrutura posicionada
                    $nrestrutMatriz = $params['NRESTRUTURAM']; // Salva o número da estrutura matriz e insere os envios sempre na matriz
                    foreach ($estruturas as $estrutura) {
                        if (isset($params['PARENT']) && !is_null($params['PARENT']) && $params['NRESTRUTURAM'] != $estrutura->getNrestruturam()) {
                            continue;
                        }
                        $params['NRESTRUTURAM'] = $estrutura->getNrestruturam();
                        $itensEstrut = $repository->$method($params);
                        $itens = array_merge($itens, $itensEstrut);
                    }
                    $params['NRESTRUTURAM'] = $nrestrutMatriz;
                }

                return $itens;
            } else {
                if(!$jenkins){
                    throw new \Exception(Messages::HCM09000_ESO_CALLED_EVENTO_ERROR,Messages::ERROR_MESSAGE_CODE);
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

    private function getRepository($nmevento) {
        $repositoryClass = "\Eso\Repository\Esocial\\" . $nmevento . "Repository";

        $repository = new $repositoryClass($this->entityManager, $this->environment);
        return $repository;
    }

    public function beforeInsertNaoPeriodico($nrorg, $nrtpambiente, $nrestruturam, $cdcnpjempregador, $nrvinculom, $dtmescompetenc, $nmevento, $nrchave, $nrtabela, $idoperacao, $jenkins = false) {
        try {
            $dtCompetencia = DateUtil::getDataDeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO_DATAHORA);

            //Verifica se tem envio de admissão para o vínculo nos no esocial simplificado
            $enviosAdmissao = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnvioAdmissaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            if (!$enviosAdmissao) {
                //Verifica se tem envio de admissão para o vínculo nos na versão antiga
                $enviosAdmissao = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnvioAdmissaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            }

            if (($nmevento == "S-2190" || $nmevento == "S-2200" || $nmevento == "S-2300") && !empty($enviosAdmissao)) {
                throw new \Exception("Vínculo ".$nrvinculom." já possui evento de admissão",Messages::ALERT_MESSAGE_CODE);
            }

            if ($nmevento != "S-2190" && $nmevento != "S-2200" && $nmevento != "S-2300" && $nmevento != "S-2210" && $nmevento != "S-2220" && $nmevento != "S-2221" && $nmevento != "S-2240" && $nmevento != "S-2500" && $nmevento != "S-2501" && empty($enviosAdmissao)) {
                throw new \Exception("Não foi encontrado evento de admissão para o vínculo ".$nrvinculom,Messages::ALERT_MESSAGE_CODE);
            }

            if ($nmevento != "S-2205" && $nmevento != "S-2210" && $nmevento != "S-2220" && $nmevento != "S-2221" && $nmevento != "S-2240" && !empty($enviosAdmissao)) {
                foreach ($enviosAdmissao as $envioAdmissao) {
                    if($envioAdmissao->getDtmescompetenc() && DateUtil::comparaDatas($dtCompetencia,$envioAdmissao->getDtmescompetenc(),DateUtil::ANTES)) {
                        throw new \Exception("Vínculo ".$nrvinculom." já possui evento de admissão com o mesmo histórico",Messages::ALERT_MESSAGE_CODE);
                    }
                }
            }

            //Verifica se tem envio de rescisão para o vínculo nos no esocial simplificado
            $enviosRescisao = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnvioRescisaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia, ['C','A']);
            if (!$enviosRescisao) {
                //Verifica se tem envio de rescisão para o vínculo nos na versão antiga
                $enviosRescisao = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnvioRescisaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            }

            if ($nmevento != "S-2205" && $nmevento != "S-2299" && $nmevento != "S-2399" && $nmevento != "S-2210" && $nmevento != "S-2220" && $nmevento != "S-2221" && $nmevento != "S-2240" && $nmevento != "S-2298") {
                if (!empty($enviosRescisao)) {
                    throw new \Exception("Foi encontrado evento de desligamento para o vínculo ".$nrvinculom,Messages::ALERT_MESSAGE_CODE);
                }
            }

            $esoEnviocadastros = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosEvento(
                $this->environment->getNrOrgTrab(), $nmevento, $nrestruturam, $nrtpambiente, 'S', $nrchave
            );
            $esoNaoperiodico = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnviosEvento(
                $this->environment->getNrOrgTrab(), $nmevento, $nrestruturam, $nrtpambiente, $nrvinculom, 'S', $nrchave, $nrtabela, [$idoperacao, 'I', 'R'], 'N'
            );
            $envios = array_merge($esoEnviocadastros, $esoNaoperiodico);

            if (!empty($envios)) {
                foreach ($envios as $envio) {
                    if (!$envio->getNrenvioexcl()) {
                        // Valida se já existe o evento com a mesma chave, mesma operação e mesma competência ou competência maior
                        if (!DateUtil::comparaDatas($dtCompetencia,$envio->getDtmescompetenc(),DateUtil::DEPOIS)) {
                            throw new \Exception(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR,Messages::ALERT_MESSAGE_CODE);
                        } else {
                            // Se não existir verifica se existe outro com competencia anterior e exlui para não gerar dois envios para o mesmo histórico
                            if ($envio->getDtmescompetenc() < $dtCompetencia && $nmevento != 'S-2230' && $nmevento != 'S-2240') {
                                // Se status pendente, com erro de envio ou com erro de processamento inativa o envio para não perder o registro de tentativa de envio protocolo/recibo
                                if ($envio->getIdstatus() == 'P' || $envio->getIdstatus() == 'E' || $envio->getIdstatus() == 'R') {
                                    $envio->setIdativo('N');
                                    $envio->setDtultatu(DateUtil::getDataAtual());
                                    $envio->setCdoperultatu($this->environment->getCdoperador());
                                    $envio->setNrorgultatu($this->environment->getNrOrgTrab());
                                    $this->entityManager->persist($envio);
                                    $this->entityManager->flush();
                                }
                            }
                        }
                    } else {
                        // Caso exista uma exclusão ou retificação para um evento já incluído, verifica se a exclusão/retificação está concluída para permitir incluir um novo
                        $envioexcl = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findOneBy(array('nrorg' => $envio->getNrorg(), 'nrenvio' => $envio->getNrenvioexcl()));
                        if ($envioexcl) {
                            if ($envioexcl->getIdstatus() != 'A' && $envioexcl->getIdstatus() != 'C') {
                                throw new \Exception("Existe um evento de exclusão ou retificação para o vínculo ".$nrvinculom.", porém ele não foi concluído",Messages::ALERT_MESSAGE_CODE);
                            }
                        }
                    }
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

}