<?php
/**
 * Created by PhpStorm.
 * User: felipesantos
 * Date: 25/08/2017
 * Time: 10:22
 */
namespace HCM\Geral\Factory;

use Doctrine\ORM\EntityManager;
use HCM\Geral\Repository\ESocialEventoNaoPerRepository;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;

class ESocialNaoPerFactory {

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, ESocialEventoNaoPerRepository $eSocialEventoNaoPerRepository)
    {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->eSocialEventoNaoPerRepository = $eSocialEventoNaoPerRepository;
    }

    /* Evento S-2190 */
    public function getDadosS2190($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2190($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    /* Evento S-2200 */
    public function getDadosS2200($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            
            /* Se for retificação do evento utiliza a data de envio do original para considerar as mesmas situações da época do primeiro envio */
            $dataEnvioOrig = null;
            if ($parametros['IDOPERACAO'] == 'R') {
                $dataEnvioOrig = $parametros['DTRESPOSTAORIG'];
            }
            
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2200($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $dataHistorico, $dataEnvioOrig);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2200dependente($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2200dependente($parametros['NRORG'], $parametros['NRPARCNEGOCIO'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2200horario($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2200horario($parametros['NRORG'], $parametros['NRESCALATRABM'], $parametros['NRTURNO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    

    /* Evento S-2205 */
    public function getDadosS2205($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2205($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $dataHistorico);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2205dependente($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2200dependente($parametros['NRORG'], $parametros['NRPARCNEGOCIO'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    

    /* Evento S-2206 */
    public function getDadosS2206($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2206($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $dataHistorico);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2206horario($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2200horario($parametros['NRORG'], $parametros['NRESCALATRABM'], $parametros['NRTURNO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2210 */
    public function getDadosS2210($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2210($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2210parteAtingida($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2210parteAtingida($parametros['NRORG'], $parametros['NRVITIMA']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2210agenteCausador($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2210agenteCausador($parametros['NRORG'], $parametros['NRVITIMA']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2220 */
    public function getDadosS2220($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2220($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /* Evento S-2220exame */
    public function getDadosS2220exame($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2220exame($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2221 */
    public function getDadosS2221($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2221($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2230 */
    public function getDadosS2230($parametros) {
        try {
            if ($parametros['NRTABELA'] == 2) {
                $dados = $this->eSocialEventoNaoPerRepository->getDadosS2230_GozoFerias($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $parametros['DTMESCOMPETENC']);
            } else {
                $dados = $this->eSocialEventoNaoPerRepository->getDadosS2230_Altesitufunc($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $parametros['DTMESCOMPETENC']);
            }
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    public function getDadosS2230infoAtestado($parametros) {
        try {
            /*Só é gerado para os códigos de motivos de afastamento 01, 03 e 35*/
            if ($parametros['DSORIGEM'] == 'AFASTAMENTO' && ($parametros['CODMOTAFAST'] == '01' || $parametros['CODMOTAFAST'] == '03' || $parametros['CODMOTAFAST'] == '35')) {
                $dados = $this->eSocialEventoNaoPerRepository->getDadosS2230infoAtestado($parametros['NRORG'], $parametros['NRCHAVE']);
            } else {
                $dados = array();
            }
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2240 */
    public function getDadosS2240($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2240($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /* Evento S-2240ativPericInsal */
    public function getDadosS2240ativPericInsal($parametros) {
        try {
            return $dados;
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2240ativPericInsal($parametros['NRORG'], $parametros['NRVINCULOM']);
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /* Evento S-2240infoAmb */
    public function getDadosS2240infoAmb($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2240infoAmb($parametros['NRORG'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /* Evento S-2240fatRisco */
    public function getDadosS2240fatRisco($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2240fatRisco($parametros['NRORG'], $parametros['NRESTRUTURAM'], $parametros['NRCARGO'], $parametros['NRFUNCAO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /* Evento S-2240epi */
    public function getDadosS2240epi($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2240epi($parametros['NRORG'], $parametros['NRFATORRISCO'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2241 */
    public function getDadosS2241($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2241($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2250 */
    public function getDadosS2250($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2250($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2260 */
    public function getDadosS2260($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2260($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2298 */
    public function getDadosS2298($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2298($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2299 */
    public function getDadosS2299($parametros) {
        try {
            if(array_key_exists('DTMESCOMPETENC', $parametros) && !empty($parametros['DTMESCOMPETENC'])){
                $parametros['DTMESCOMPETENC'] = DateUtil::getPrimeiroDiaDoMes(DateUtil::getDatadeString(substr($parametros['DTMESCOMPETENC'], 0, 10)))->format('d/m/Y') ;
            }else{
                $parametros['DTMESCOMPETENC'] = $this->hcmParameters->getDtCompetencia();
            }  
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299observacoes($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299observacoes($parametros['NRORG'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299dmDev($parametros) {
        try {
            //N (se {mtvDeslig} = [11, 12, 13, 25, 28, 29, 30, 34, 36] OU se {dtDeslig} for anterior ao início de obrigatoriedade dos eventos periódicos para o empregador);
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299dmDev($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['DTRESCISAOVINC'], $parametros['NRESTRUTLEGAL'], $parametros['NRESTRUTGEREN'], $parametros['CDCATEGTRAB'], $parametros['NRTPAMBIENTE'], $parametros['MTVDESLIG'], $parametros['INIVALIDADEAMB'], $parametros['NRPESSOA'], $parametros['NRINSC'], $parametros['DTMESCOMPETENC'], $parametros['NRAGENTENOCIVO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299ideEstabLot($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299ideEstabLot($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['NRESTRUTLEGAL'], $parametros['NRESTRUTGEREN'], $parametros['CDCATEGTRAB'], $parametros['DTMESCOMPETENC'], $parametros['NRAGENTENOCIVO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299detVerbas($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299detVerbas($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299detOper($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299detOper($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299detPlano($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299detPlano($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['CDCNPJESTRUT'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299procJudTrab($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299procJudTrab($parametros['NRORG'], $parametros['NRESTRUTLEGAL'], $parametros['NRPARCNEGOCIO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2299remunOutrEmpr($parametros) {
        try {
            if (!is_null($parametros['INDMV'])) {
                $dados = $this->eSocialEventoNaoPerRepository->getDadosS2299remunOutrEmpr($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRPESSOA'], $parametros['DTMESCOMPETENC']);
                return $dados;
            }
            return array();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2300 */
    public function getDadosS2300($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            
            /* Se for retificação do evento utiliza a data de envio do original para considerar as mesmas situações da época do primeiro envio */
            $dataEnvioOrig = null;
            if ($parametros['IDOPERACAO'] == 'R') {
                $dataEnvioOrig = $parametros['DTRESPOSTAORIG'];
            }
            
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2300($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $dataHistorico, $dataEnvioOrig);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2300dependente($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2300dependente($parametros['NRORG'], $parametros['NRPARCNEGOCIO'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2306 */
    public function getDadosS2306($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2306($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $dataHistorico);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Evento S-2399 */
    public function getDadosS2399($parametros) {
        try {
            $parametros['DTMESCOMPETENC'] = array_key_exists('DTMESCOMPETENC', $parametros) ? DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($parametros['DTMESCOMPETENC']))->format('d/m/Y') : $this->hcmParameters->getDtCompetencia(); 
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399dmDev($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399dmDev($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['DTRESCISAOVINC'], $parametros['NRESTRUTLEGAL'], $parametros['NRESTRUTGEREN'], $parametros['CDCATEGTRAB'], $parametros['INIVALIDADEAMB'], $parametros['DTMESCOMPETENC'], $parametros['NRAGENTENOCIVO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399ideEstabLot($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399ideEstabLot($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['NRESTRUTLEGAL'], $parametros['NRESTRUTGEREN'], $parametros['CDCATEGTRAB'], $parametros['DTMESCOMPETENC'], $parametros['NRAGENTENOCIVO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399detVerbas($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399detVerbas($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399detOper($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399detOper($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399detPlano($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399detPlano($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRCALCULOFOLHA'], $parametros['CDCNPJESTRUT'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399procJudTrab($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399procJudTrab($parametros['NRORG'], $parametros['NRESTRUTLEGAL'], $parametros['NRPARCNEGOCIO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS2399remunOutrEmpr($parametros) {
        try {
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS2399remunOutrEmpr($parametros['NRORG'], $parametros['NRVINCULOM'], $parametros['NRPESSOA'], $parametros['DTMESCOMPETENC']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }


    /* Evento S-3000 */
    public function getDadosS3000($parametros) {
        try {
            $nrIdeTrabalhador = null; //Caso o evento a ser excluído seja relacionado à algum trabalhador
            $nrIdeFolhaPgto = null; //Caso o evento a ser excluído seja relacionado à folha de pagamento
            
            /* Busca identificador do trabalhador ou da apuração, conforme o evento a ser excluído*/
            if (array_search($parametros['NMEVENTOORIG'], array('S-2200', 'S-2205', 'S-2206', 'S-2250', 'S-2298', 'S-2299', 'S-2300', 'S-2306', 'S-2399')) !== false) {
                $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array('nrorg' => $parametros['NRORG'], 'nrvinculom' => $parametros['NRCHAVE']));
                $nrIdeTrabalhador = is_object($vinculo) ? $vinculo->getNrpessoa() : null;
            }
            else if ($parametros['NMEVENTOORIG'] == 'S-1200') {
                $nrIdeTrabalhador = $parametros['NRCHAVE'];
                $calculo = $this->entityManager->getRepository(Repositories::FPA_CALCULOFOLHA)->findOneBy(
                    array('nrorg' => $parametros['NRORG'], 'dtocorrencia' => $parametros['DTMESCOMPORIG'], 'nrtipomoviment' => ($parametros['NRTABELA'] == 4 ? 4 : [1,2,10,19]), 'nrtpmodalidcal' => 1)
                );
                $nrIdeFolhaPgto = is_object($calculo) ? $calculo->getNrcalculofolha() : null;
            }
            else if ($parametros['NMEVENTOORIG'] == 'S-2190' || $parametros['NMEVENTOORIG'] == 'S-1210') {
                $nrIdeTrabalhador = $parametros['NRCHAVE'];
            }
            else if ($parametros['NMEVENTOORIG'] == 'S-2230') {
                if ($parametros['NRTABELA'] == 2) {
                    $gozoferias = $this->entityManager->getRepository(Repositories::FPA_GOZOFERIAS)->findOneBy(array('nrorg' => $parametros['NRORG'], 'nrgozoferias' => $parametros['NRCHAVE']));
                    if (is_object($gozoferias)) {
                        $ferias = $this->entityManager->getRepository(Repositories::FPA_FERIAS)->findOneBy(array('nrorg' => $gozoferias->getNrorg(), 'nrferias' => $gozoferias->getNrferias()));
                        $nrvinculom = is_object($ferias) ? $ferias->getNrvinculom() : null;
                        $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array('nrorg' => $parametros['NRORG'], 'nrvinculom' => $nrvinculom));
                        $nrIdeTrabalhador = is_object($vinculo) ? $vinculo->getNrpessoa() : null;
                    }
                } else {
                    $altesitufunc = $this->entityManager->getRepository(Repositories::GPE_ALTESITUFUNC)->findOneBy(array('nrorg' => $parametros['NRORG'], 'nraltesitufunc' => $parametros['NRCHAVE']));
                    $nrvinculom = is_object($altesitufunc) ? $altesitufunc->getNrvinculom() : null;
                    $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array('nrorg' => $parametros['NRORG'], 'nrvinculom' => $nrvinculom));
                    $nrIdeTrabalhador = is_object($vinculo) ? $vinculo->getNrpessoa() : null;
                }
            }
            
            $dados = $this->eSocialEventoNaoPerRepository->getDadosS3000(
                $parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRENVIOORIG'], $nrIdeTrabalhador, $nrIdeFolhaPgto
            );
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

}